// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/iam/v1/oauth_client.proto

package iam

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type OAuthClient_Status int32

const (
	OAuthClient_STATUS_UNSPECIFIED OAuthClient_Status = 0
	// OAuth client is being created.
	OAuthClient_CREATING OAuthClient_Status = 1
	// OAuth client is active.
	OAuthClient_ACTIVE OAuthClient_Status = 2
	// OAuth client is being deleted.
	OAuthClient_DELETING OAuthClient_Status = 3
)

// Enum value maps for OAuthClient_Status.
var (
	OAuthClient_Status_name = map[int32]string{
		0: "STATUS_UNSPECIFIED",
		1: "CREATING",
		2: "ACTIVE",
		3: "DELETING",
	}
	OAuthClient_Status_value = map[string]int32{
		"STATUS_UNSPECIFIED": 0,
		"CREATING":           1,
		"ACTIVE":             2,
		"DELETING":           3,
	}
)

func (x OAuthClient_Status) Enum() *OAuthClient_Status {
	p := new(OAuthClient_Status)
	*p = x
	return p
}

func (x OAuthClient_Status) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (OAuthClient_Status) Descriptor() protoreflect.EnumDescriptor {
	return file_yandex_cloud_iam_v1_oauth_client_proto_enumTypes[0].Descriptor()
}

func (OAuthClient_Status) Type() protoreflect.EnumType {
	return &file_yandex_cloud_iam_v1_oauth_client_proto_enumTypes[0]
}

func (x OAuthClient_Status) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use OAuthClient_Status.Descriptor instead.
func (OAuthClient_Status) EnumDescriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_oauth_client_proto_rawDescGZIP(), []int{0, 0}
}

// An OauthClient resource.
type OAuthClient struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the oauth client.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// Name for the oauth client.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// List of redirect uries allowed for the oauth client.
	RedirectUris []string `protobuf:"bytes,3,rep,name=redirect_uris,json=redirectUris,proto3" json:"redirect_uris,omitempty"`
	// List of oauth scopes requested by the oauth client.
	Scopes []string `protobuf:"bytes,4,rep,name=scopes,proto3" json:"scopes,omitempty"`
	// ID of the folder oauth client belongs to.
	FolderId string `protobuf:"bytes,5,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// Current status of the oauth client.
	Status        OAuthClient_Status `protobuf:"varint,6,opt,name=status,proto3,enum=yandex.cloud.iam.v1.OAuthClient_Status" json:"status,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OAuthClient) Reset() {
	*x = OAuthClient{}
	mi := &file_yandex_cloud_iam_v1_oauth_client_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OAuthClient) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OAuthClient) ProtoMessage() {}

func (x *OAuthClient) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_oauth_client_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OAuthClient.ProtoReflect.Descriptor instead.
func (*OAuthClient) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_oauth_client_proto_rawDescGZIP(), []int{0}
}

func (x *OAuthClient) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *OAuthClient) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *OAuthClient) GetRedirectUris() []string {
	if x != nil {
		return x.RedirectUris
	}
	return nil
}

func (x *OAuthClient) GetScopes() []string {
	if x != nil {
		return x.Scopes
	}
	return nil
}

func (x *OAuthClient) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *OAuthClient) GetStatus() OAuthClient_Status {
	if x != nil {
		return x.Status
	}
	return OAuthClient_STATUS_UNSPECIFIED
}

var File_yandex_cloud_iam_v1_oauth_client_proto protoreflect.FileDescriptor

const file_yandex_cloud_iam_v1_oauth_client_proto_rawDesc = "" +
	"\n" +
	"&yandex/cloud/iam/v1/oauth_client.proto\x12\x13yandex.cloud.iam.v1\"\x96\x02\n" +
	"\vOAuthClient\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n" +
	"\x04name\x18\x02 \x01(\tR\x04name\x12#\n" +
	"\rredirect_uris\x18\x03 \x03(\tR\fredirectUris\x12\x16\n" +
	"\x06scopes\x18\x04 \x03(\tR\x06scopes\x12\x1b\n" +
	"\tfolder_id\x18\x05 \x01(\tR\bfolderId\x12?\n" +
	"\x06status\x18\x06 \x01(\x0e2'.yandex.cloud.iam.v1.OAuthClient.StatusR\x06status\"H\n" +
	"\x06Status\x12\x16\n" +
	"\x12STATUS_UNSPECIFIED\x10\x00\x12\f\n" +
	"\bCREATING\x10\x01\x12\n" +
	"\n" +
	"\x06ACTIVE\x10\x02\x12\f\n" +
	"\bDELETING\x10\x03BV\n" +
	"\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3"

var (
	file_yandex_cloud_iam_v1_oauth_client_proto_rawDescOnce sync.Once
	file_yandex_cloud_iam_v1_oauth_client_proto_rawDescData []byte
)

func file_yandex_cloud_iam_v1_oauth_client_proto_rawDescGZIP() []byte {
	file_yandex_cloud_iam_v1_oauth_client_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_iam_v1_oauth_client_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_oauth_client_proto_rawDesc), len(file_yandex_cloud_iam_v1_oauth_client_proto_rawDesc)))
	})
	return file_yandex_cloud_iam_v1_oauth_client_proto_rawDescData
}

var file_yandex_cloud_iam_v1_oauth_client_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_yandex_cloud_iam_v1_oauth_client_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_yandex_cloud_iam_v1_oauth_client_proto_goTypes = []any{
	(OAuthClient_Status)(0), // 0: yandex.cloud.iam.v1.OAuthClient.Status
	(*OAuthClient)(nil),     // 1: yandex.cloud.iam.v1.OAuthClient
}
var file_yandex_cloud_iam_v1_oauth_client_proto_depIdxs = []int32{
	0, // 0: yandex.cloud.iam.v1.OAuthClient.status:type_name -> yandex.cloud.iam.v1.OAuthClient.Status
	1, // [1:1] is the sub-list for method output_type
	1, // [1:1] is the sub-list for method input_type
	1, // [1:1] is the sub-list for extension type_name
	1, // [1:1] is the sub-list for extension extendee
	0, // [0:1] is the sub-list for field type_name
}

func init() { file_yandex_cloud_iam_v1_oauth_client_proto_init() }
func file_yandex_cloud_iam_v1_oauth_client_proto_init() {
	if File_yandex_cloud_iam_v1_oauth_client_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_oauth_client_proto_rawDesc), len(file_yandex_cloud_iam_v1_oauth_client_proto_rawDesc)),
			NumEnums:      1,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_yandex_cloud_iam_v1_oauth_client_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_iam_v1_oauth_client_proto_depIdxs,
		EnumInfos:         file_yandex_cloud_iam_v1_oauth_client_proto_enumTypes,
		MessageInfos:      file_yandex_cloud_iam_v1_oauth_client_proto_msgTypes,
	}.Build()
	File_yandex_cloud_iam_v1_oauth_client_proto = out.File
	file_yandex_cloud_iam_v1_oauth_client_proto_goTypes = nil
	file_yandex_cloud_iam_v1_oauth_client_proto_depIdxs = nil
}
