// Code generated by protoc-gen-go-grpc. DO NOT EDIT.
// versions:
// - protoc-gen-go-grpc v1.6.1
// - protoc             v3.21.12
// source: yandex/cloud/dns/v1/dns_endpoint_service.proto

package dns

import (
	context "context"
	access "github.com/yandex-cloud/go-genproto/yandex/cloud/access"
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
// Requires gRPC-Go v1.64.0 or later.
const _ = grpc.SupportPackageIsVersion9

const (
	DnsInboundEndpointService_Get_FullMethodName                  = "/yandex.cloud.dns.v1.DnsInboundEndpointService/Get"
	DnsInboundEndpointService_List_FullMethodName                 = "/yandex.cloud.dns.v1.DnsInboundEndpointService/List"
	DnsInboundEndpointService_Create_FullMethodName               = "/yandex.cloud.dns.v1.DnsInboundEndpointService/Create"
	DnsInboundEndpointService_Update_FullMethodName               = "/yandex.cloud.dns.v1.DnsInboundEndpointService/Update"
	DnsInboundEndpointService_Delete_FullMethodName               = "/yandex.cloud.dns.v1.DnsInboundEndpointService/Delete"
	DnsInboundEndpointService_ListOperations_FullMethodName       = "/yandex.cloud.dns.v1.DnsInboundEndpointService/ListOperations"
	DnsInboundEndpointService_ListAccessBindings_FullMethodName   = "/yandex.cloud.dns.v1.DnsInboundEndpointService/ListAccessBindings"
	DnsInboundEndpointService_SetAccessBindings_FullMethodName    = "/yandex.cloud.dns.v1.DnsInboundEndpointService/SetAccessBindings"
	DnsInboundEndpointService_UpdateAccessBindings_FullMethodName = "/yandex.cloud.dns.v1.DnsInboundEndpointService/UpdateAccessBindings"
)

// DnsInboundEndpointServiceClient is the client API for DnsInboundEndpointService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
type DnsInboundEndpointServiceClient interface {
	// Returns the specified DNS inbound endpoint.
	// To get the list of all available DNS inbound endpoints, make a [List] request.
	Get(ctx context.Context, in *GetDnsInboundEndpointRequest, opts ...grpc.CallOption) (*DnsInboundEndpoint, error)
	// Retrieves the list of DNS inbound endpoints in the specified folder.
	List(ctx context.Context, in *ListDnsInboundEndpointsRequest, opts ...grpc.CallOption) (*ListDnsInboundEndpointsResponse, error)
	// Creates a DNS inbound endpoint in the specified folder.
	Create(ctx context.Context, in *CreateDnsInboundEndpointRequest, opts ...grpc.CallOption) (*operation.Operation, error)
	// Updates the specified DNS inbound endpoint.
	Update(ctx context.Context, in *UpdateDnsInboundEndpointRequest, opts ...grpc.CallOption) (*operation.Operation, error)
	// Deletes the specified DNS inbound endpoint.
	Delete(ctx context.Context, in *DeleteDnsInboundEndpointRequest, opts ...grpc.CallOption) (*operation.Operation, error)
	// Lists operations for the specified DNS inbound endpoint.
	ListOperations(ctx context.Context, in *ListDnsInboundEndpointOperationsRequest, opts ...grpc.CallOption) (*ListDnsInboundEndpointOperationsResponse, error)
	// Lists existing access bindings for the specified DNS inbound endpoint.
	ListAccessBindings(ctx context.Context, in *access.ListAccessBindingsRequest, opts ...grpc.CallOption) (*access.ListAccessBindingsResponse, error)
	// Sets access bindings for the specified DNS inbound endpoint.
	SetAccessBindings(ctx context.Context, in *access.SetAccessBindingsRequest, opts ...grpc.CallOption) (*operation.Operation, error)
	// Updates access bindings for the specified DNS inbound endpoint.
	UpdateAccessBindings(ctx context.Context, in *access.UpdateAccessBindingsRequest, opts ...grpc.CallOption) (*operation.Operation, error)
}

type dnsInboundEndpointServiceClient struct {
	cc grpc.ClientConnInterface
}

func NewDnsInboundEndpointServiceClient(cc grpc.ClientConnInterface) DnsInboundEndpointServiceClient {
	return &dnsInboundEndpointServiceClient{cc}
}

func (c *dnsInboundEndpointServiceClient) Get(ctx context.Context, in *GetDnsInboundEndpointRequest, opts ...grpc.CallOption) (*DnsInboundEndpoint, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(DnsInboundEndpoint)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_Get_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) List(ctx context.Context, in *ListDnsInboundEndpointsRequest, opts ...grpc.CallOption) (*ListDnsInboundEndpointsResponse, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(ListDnsInboundEndpointsResponse)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_List_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) Create(ctx context.Context, in *CreateDnsInboundEndpointRequest, opts ...grpc.CallOption) (*operation.Operation, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(operation.Operation)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_Create_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) Update(ctx context.Context, in *UpdateDnsInboundEndpointRequest, opts ...grpc.CallOption) (*operation.Operation, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(operation.Operation)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_Update_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) Delete(ctx context.Context, in *DeleteDnsInboundEndpointRequest, opts ...grpc.CallOption) (*operation.Operation, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(operation.Operation)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_Delete_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) ListOperations(ctx context.Context, in *ListDnsInboundEndpointOperationsRequest, opts ...grpc.CallOption) (*ListDnsInboundEndpointOperationsResponse, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(ListDnsInboundEndpointOperationsResponse)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_ListOperations_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) ListAccessBindings(ctx context.Context, in *access.ListAccessBindingsRequest, opts ...grpc.CallOption) (*access.ListAccessBindingsResponse, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(access.ListAccessBindingsResponse)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_ListAccessBindings_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) SetAccessBindings(ctx context.Context, in *access.SetAccessBindingsRequest, opts ...grpc.CallOption) (*operation.Operation, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(operation.Operation)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_SetAccessBindings_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *dnsInboundEndpointServiceClient) UpdateAccessBindings(ctx context.Context, in *access.UpdateAccessBindingsRequest, opts ...grpc.CallOption) (*operation.Operation, error) {
	cOpts := append([]grpc.CallOption{grpc.StaticMethod()}, opts...)
	out := new(operation.Operation)
	err := c.cc.Invoke(ctx, DnsInboundEndpointService_UpdateAccessBindings_FullMethodName, in, out, cOpts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// DnsInboundEndpointServiceServer is the server API for DnsInboundEndpointService service.
// All implementations should embed UnimplementedDnsInboundEndpointServiceServer
// for forward compatibility.
type DnsInboundEndpointServiceServer interface {
	// Returns the specified DNS inbound endpoint.
	// To get the list of all available DNS inbound endpoints, make a [List] request.
	Get(context.Context, *GetDnsInboundEndpointRequest) (*DnsInboundEndpoint, error)
	// Retrieves the list of DNS inbound endpoints in the specified folder.
	List(context.Context, *ListDnsInboundEndpointsRequest) (*ListDnsInboundEndpointsResponse, error)
	// Creates a DNS inbound endpoint in the specified folder.
	Create(context.Context, *CreateDnsInboundEndpointRequest) (*operation.Operation, error)
	// Updates the specified DNS inbound endpoint.
	Update(context.Context, *UpdateDnsInboundEndpointRequest) (*operation.Operation, error)
	// Deletes the specified DNS inbound endpoint.
	Delete(context.Context, *DeleteDnsInboundEndpointRequest) (*operation.Operation, error)
	// Lists operations for the specified DNS inbound endpoint.
	ListOperations(context.Context, *ListDnsInboundEndpointOperationsRequest) (*ListDnsInboundEndpointOperationsResponse, error)
	// Lists existing access bindings for the specified DNS inbound endpoint.
	ListAccessBindings(context.Context, *access.ListAccessBindingsRequest) (*access.ListAccessBindingsResponse, error)
	// Sets access bindings for the specified DNS inbound endpoint.
	SetAccessBindings(context.Context, *access.SetAccessBindingsRequest) (*operation.Operation, error)
	// Updates access bindings for the specified DNS inbound endpoint.
	UpdateAccessBindings(context.Context, *access.UpdateAccessBindingsRequest) (*operation.Operation, error)
}

// UnimplementedDnsInboundEndpointServiceServer should be embedded to have
// forward compatible implementations.
//
// NOTE: this should be embedded by value instead of pointer to avoid a nil
// pointer dereference when methods are called.
type UnimplementedDnsInboundEndpointServiceServer struct{}

func (UnimplementedDnsInboundEndpointServiceServer) Get(context.Context, *GetDnsInboundEndpointRequest) (*DnsInboundEndpoint, error) {
	return nil, status.Error(codes.Unimplemented, "method Get not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) List(context.Context, *ListDnsInboundEndpointsRequest) (*ListDnsInboundEndpointsResponse, error) {
	return nil, status.Error(codes.Unimplemented, "method List not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) Create(context.Context, *CreateDnsInboundEndpointRequest) (*operation.Operation, error) {
	return nil, status.Error(codes.Unimplemented, "method Create not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) Update(context.Context, *UpdateDnsInboundEndpointRequest) (*operation.Operation, error) {
	return nil, status.Error(codes.Unimplemented, "method Update not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) Delete(context.Context, *DeleteDnsInboundEndpointRequest) (*operation.Operation, error) {
	return nil, status.Error(codes.Unimplemented, "method Delete not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) ListOperations(context.Context, *ListDnsInboundEndpointOperationsRequest) (*ListDnsInboundEndpointOperationsResponse, error) {
	return nil, status.Error(codes.Unimplemented, "method ListOperations not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) ListAccessBindings(context.Context, *access.ListAccessBindingsRequest) (*access.ListAccessBindingsResponse, error) {
	return nil, status.Error(codes.Unimplemented, "method ListAccessBindings not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) SetAccessBindings(context.Context, *access.SetAccessBindingsRequest) (*operation.Operation, error) {
	return nil, status.Error(codes.Unimplemented, "method SetAccessBindings not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) UpdateAccessBindings(context.Context, *access.UpdateAccessBindingsRequest) (*operation.Operation, error) {
	return nil, status.Error(codes.Unimplemented, "method UpdateAccessBindings not implemented")
}
func (UnimplementedDnsInboundEndpointServiceServer) testEmbeddedByValue() {}

// UnsafeDnsInboundEndpointServiceServer may be embedded to opt out of forward compatibility for this service.
// Use of this interface is not recommended, as added methods to DnsInboundEndpointServiceServer will
// result in compilation errors.
type UnsafeDnsInboundEndpointServiceServer interface {
	mustEmbedUnimplementedDnsInboundEndpointServiceServer()
}

func RegisterDnsInboundEndpointServiceServer(s grpc.ServiceRegistrar, srv DnsInboundEndpointServiceServer) {
	// If the following call panics, it indicates UnimplementedDnsInboundEndpointServiceServer was
	// embedded by pointer and is nil.  This will cause panics if an
	// unimplemented method is ever invoked, so we test this at initialization
	// time to prevent it from happening at runtime later due to I/O.
	if t, ok := srv.(interface{ testEmbeddedByValue() }); ok {
		t.testEmbeddedByValue()
	}
	s.RegisterService(&DnsInboundEndpointService_ServiceDesc, srv)
}

func _DnsInboundEndpointService_Get_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetDnsInboundEndpointRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).Get(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_Get_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).Get(ctx, req.(*GetDnsInboundEndpointRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_List_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListDnsInboundEndpointsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).List(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_List_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).List(ctx, req.(*ListDnsInboundEndpointsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_Create_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateDnsInboundEndpointRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).Create(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_Create_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).Create(ctx, req.(*CreateDnsInboundEndpointRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_Update_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateDnsInboundEndpointRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).Update(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_Update_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).Update(ctx, req.(*UpdateDnsInboundEndpointRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_Delete_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeleteDnsInboundEndpointRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).Delete(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_Delete_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).Delete(ctx, req.(*DeleteDnsInboundEndpointRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_ListOperations_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListDnsInboundEndpointOperationsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).ListOperations(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_ListOperations_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).ListOperations(ctx, req.(*ListDnsInboundEndpointOperationsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_ListAccessBindings_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(access.ListAccessBindingsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).ListAccessBindings(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_ListAccessBindings_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).ListAccessBindings(ctx, req.(*access.ListAccessBindingsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_SetAccessBindings_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(access.SetAccessBindingsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).SetAccessBindings(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_SetAccessBindings_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).SetAccessBindings(ctx, req.(*access.SetAccessBindingsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _DnsInboundEndpointService_UpdateAccessBindings_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(access.UpdateAccessBindingsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DnsInboundEndpointServiceServer).UpdateAccessBindings(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: DnsInboundEndpointService_UpdateAccessBindings_FullMethodName,
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DnsInboundEndpointServiceServer).UpdateAccessBindings(ctx, req.(*access.UpdateAccessBindingsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

// DnsInboundEndpointService_ServiceDesc is the grpc.ServiceDesc for DnsInboundEndpointService service.
// It's only intended for direct use with grpc.RegisterService,
// and not to be introspected or modified (even as a copy)
var DnsInboundEndpointService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "yandex.cloud.dns.v1.DnsInboundEndpointService",
	HandlerType: (*DnsInboundEndpointServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Get",
			Handler:    _DnsInboundEndpointService_Get_Handler,
		},
		{
			MethodName: "List",
			Handler:    _DnsInboundEndpointService_List_Handler,
		},
		{
			MethodName: "Create",
			Handler:    _DnsInboundEndpointService_Create_Handler,
		},
		{
			MethodName: "Update",
			Handler:    _DnsInboundEndpointService_Update_Handler,
		},
		{
			MethodName: "Delete",
			Handler:    _DnsInboundEndpointService_Delete_Handler,
		},
		{
			MethodName: "ListOperations",
			Handler:    _DnsInboundEndpointService_ListOperations_Handler,
		},
		{
			MethodName: "ListAccessBindings",
			Handler:    _DnsInboundEndpointService_ListAccessBindings_Handler,
		},
		{
			MethodName: "SetAccessBindings",
			Handler:    _DnsInboundEndpointService_SetAccessBindings_Handler,
		},
		{
			MethodName: "UpdateAccessBindings",
			Handler:    _DnsInboundEndpointService_UpdateAccessBindings_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "yandex/cloud/dns/v1/dns_endpoint_service.proto",
}
