// Copyright 2018 JDCLOUD.COM
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// NOTE: This class is auto generated by the jdcloud code generator program.

package models

type BackupAddressesInfo struct {

	/* 地址 (Optional) */
	Address string `json:"address"`

	/* 备用地址1的类型，1为ip 2为域名 (Optional) */
	Type int `json:"type"`

	/* 备用地址1的状态，0正常，1异常 (Optional) */
	Status int `json:"status"`
}
