// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

import (
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
)

func (m *OAuthClientSecret) SetId(v string) {
	m.Id = v
}

func (m *OAuthClientSecret) SetOauthClientId(v string) {
	m.OauthClientId = v
}

func (m *OAuthClientSecret) SetDescription(v string) {
	m.Description = v
}

func (m *OAuthClientSecret) SetMaskedSecret(v string) {
	m.MaskedSecret = v
}

func (m *OAuthClientSecret) SetCreatedAt(v *timestamppb.Timestamp) {
	m.CreatedAt = v
}
