// Code generated by protoc-gen-goext. DO NOT EDIT.

package endpoint

func (m *GetApiEndpointRequest) SetApiEndpointId(v string) {
	m.ApiEndpointId = v
}

func (m *ListApiEndpointsRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListApiEndpointsRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListApiEndpointsResponse) SetEndpoints(v []*ApiEndpoint) {
	m.Endpoints = v
}

func (m *ListApiEndpointsResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}
