// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/dns/v1/dns_firewall_service.proto

package dns

import (
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud"
	access "github.com/yandex-cloud/go-genproto/yandex/cloud/access"
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud/api"
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	fieldmaskpb "google.golang.org/protobuf/types/known/fieldmaskpb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GetDnsFirewallRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall to return.
	// To get a DNS firewall ID, make a [DnsFirewallService.List] request.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetDnsFirewallRequest) Reset() {
	*x = GetDnsFirewallRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetDnsFirewallRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetDnsFirewallRequest) ProtoMessage() {}

func (x *GetDnsFirewallRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetDnsFirewallRequest.ProtoReflect.Descriptor instead.
func (*GetDnsFirewallRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{0}
}

func (x *GetDnsFirewallRequest) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

type ListDnsFirewallsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the folder to list DNS firewalls in.
	// To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
	FolderId string `protobuf:"bytes,1,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// The maximum number of results per page to return. If the number of available
	// results is larger than `page_size`, the service returns a [ListDnsFirewallsResponse.next_page_token]
	// that can be used to get the next page of results in subsequent list requests.
	PageSize int64 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Page token. To get the next page of results, set `page_token` to the
	// [ListDnsFirewallsResponse.next_page_token] returned by a previous list request.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// A filter expression that filters DNS firewalls listed in the response.
	// The expression must specify:
	// 1. The field name. Currently you can use filtering only on the [DnsFirewall.name] field.
	// 2. An `=` operator.
	// 3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
	// Example of a filter: `name=my-dns-firewall`.
	Filter        string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsFirewallsRequest) Reset() {
	*x = ListDnsFirewallsRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsFirewallsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsFirewallsRequest) ProtoMessage() {}

func (x *ListDnsFirewallsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsFirewallsRequest.ProtoReflect.Descriptor instead.
func (*ListDnsFirewallsRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{1}
}

func (x *ListDnsFirewallsRequest) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *ListDnsFirewallsRequest) GetPageSize() int64 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListDnsFirewallsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListDnsFirewallsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

type ListDnsFirewallsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// List of DNS firewalls in the specified folder.
	DnsFirewalls []*DnsFirewall `protobuf:"bytes,1,rep,name=dns_firewalls,json=dnsFirewalls,proto3" json:"dns_firewalls,omitempty"`
	// Token for getting the next page of the list. If the number of results is greater than
	// the specified [ListDnsFirewallsRequest.page_size], use `next_page_token` as the value
	// for the [ListDnsFirewallsRequest.page_token] parameter in the next list request.
	// Each subsequent page will have its own `next_page_token` to continue paging through the results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsFirewallsResponse) Reset() {
	*x = ListDnsFirewallsResponse{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsFirewallsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsFirewallsResponse) ProtoMessage() {}

func (x *ListDnsFirewallsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsFirewallsResponse.ProtoReflect.Descriptor instead.
func (*ListDnsFirewallsResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{2}
}

func (x *ListDnsFirewallsResponse) GetDnsFirewalls() []*DnsFirewall {
	if x != nil {
		return x.DnsFirewalls
	}
	return nil
}

func (x *ListDnsFirewallsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

type CreateDnsFirewallRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the folder to create DNS firewalls in.
	// To get a folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
	FolderId string `protobuf:"bytes,1,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// Name of the DNS firewall.
	// The name must be unique within the folder.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// Description of the DNS firewall.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// DNS firewall labels as `key:value` pairs.
	Labels map[string]string `protobuf:"bytes,4,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// Prevents accidental firewall removal.
	DeletionProtection bool `protobuf:"varint,5,opt,name=deletion_protection,json=deletionProtection,proto3" json:"deletion_protection,omitempty"`
	// Whether the DNS firewall is enabled.
	Enabled bool `protobuf:"varint,6,opt,name=enabled,proto3" json:"enabled,omitempty"`
	// Resource settings.
	// Specifies resources that the DNS firewall applies to.
	ResourceConfig *DnsFirewall_ResourceConfig `protobuf:"bytes,7,opt,name=resource_config,json=resourceConfig,proto3" json:"resource_config,omitempty"`
	// List of FQDNs that the DNS firewall allows to pass.
	WhitelistFqdns []string `protobuf:"bytes,8,rep,name=whitelist_fqdns,json=whitelistFqdns,proto3" json:"whitelist_fqdns,omitempty"`
	// List of FQDNs that the DNS firewall blocks.
	BlacklistFqdns []string `protobuf:"bytes,9,rep,name=blacklist_fqdns,json=blacklistFqdns,proto3" json:"blacklist_fqdns,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *CreateDnsFirewallRequest) Reset() {
	*x = CreateDnsFirewallRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDnsFirewallRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDnsFirewallRequest) ProtoMessage() {}

func (x *CreateDnsFirewallRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDnsFirewallRequest.ProtoReflect.Descriptor instead.
func (*CreateDnsFirewallRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{3}
}

func (x *CreateDnsFirewallRequest) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *CreateDnsFirewallRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *CreateDnsFirewallRequest) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *CreateDnsFirewallRequest) GetLabels() map[string]string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *CreateDnsFirewallRequest) GetDeletionProtection() bool {
	if x != nil {
		return x.DeletionProtection
	}
	return false
}

func (x *CreateDnsFirewallRequest) GetEnabled() bool {
	if x != nil {
		return x.Enabled
	}
	return false
}

func (x *CreateDnsFirewallRequest) GetResourceConfig() *DnsFirewall_ResourceConfig {
	if x != nil {
		return x.ResourceConfig
	}
	return nil
}

func (x *CreateDnsFirewallRequest) GetWhitelistFqdns() []string {
	if x != nil {
		return x.WhitelistFqdns
	}
	return nil
}

func (x *CreateDnsFirewallRequest) GetBlacklistFqdns() []string {
	if x != nil {
		return x.BlacklistFqdns
	}
	return nil
}

type CreateDnsFirewallMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall that is being created.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateDnsFirewallMetadata) Reset() {
	*x = CreateDnsFirewallMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDnsFirewallMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDnsFirewallMetadata) ProtoMessage() {}

func (x *CreateDnsFirewallMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDnsFirewallMetadata.ProtoReflect.Descriptor instead.
func (*CreateDnsFirewallMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{4}
}

func (x *CreateDnsFirewallMetadata) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

type UpdateDnsFirewallRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall to update.
	// To get the DNS firewall ID, make a [DnsFirewallService.List] request.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	// Field mask specifying which fields of the DNS firewall resource are going to be updated.
	UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// New name for the DNS firewall.
	// The name must be unique within the folder.
	Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// New description of the DNS firewall.
	Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
	// DNS firewall labels as `key:value` pairs.
	// Existing set of labels is completely replaced by the provided set, so if you just want
	// to add or remove a label:
	// 1. Get the current set of labels with a [DnsFirewallService.Get] request.
	// 2. Add or remove a label in this set.
	// 3. Send the new set in this field.
	Labels map[string]string `protobuf:"bytes,5,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// Prevents accidental firewall removal.
	DeletionProtection bool `protobuf:"varint,6,opt,name=deletion_protection,json=deletionProtection,proto3" json:"deletion_protection,omitempty"`
	// Whether the DNS firewall is enabled.
	Enabled bool `protobuf:"varint,7,opt,name=enabled,proto3" json:"enabled,omitempty"`
	// Resource settings.
	// Specifies resources that the DNS firewall applies to.
	ResourceConfig *DnsFirewall_ResourceConfig `protobuf:"bytes,8,opt,name=resource_config,json=resourceConfig,proto3" json:"resource_config,omitempty"`
	// List of FQDNs that the DNS firewall allows to pass.
	WhitelistFqdns []string `protobuf:"bytes,9,rep,name=whitelist_fqdns,json=whitelistFqdns,proto3" json:"whitelist_fqdns,omitempty"`
	// List of FQDNs that the DNS firewall blocks.
	BlacklistFqdns []string `protobuf:"bytes,10,rep,name=blacklist_fqdns,json=blacklistFqdns,proto3" json:"blacklist_fqdns,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *UpdateDnsFirewallRequest) Reset() {
	*x = UpdateDnsFirewallRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateDnsFirewallRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateDnsFirewallRequest) ProtoMessage() {}

func (x *UpdateDnsFirewallRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateDnsFirewallRequest.ProtoReflect.Descriptor instead.
func (*UpdateDnsFirewallRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{5}
}

func (x *UpdateDnsFirewallRequest) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

func (x *UpdateDnsFirewallRequest) GetUpdateMask() *fieldmaskpb.FieldMask {
	if x != nil {
		return x.UpdateMask
	}
	return nil
}

func (x *UpdateDnsFirewallRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *UpdateDnsFirewallRequest) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *UpdateDnsFirewallRequest) GetLabels() map[string]string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *UpdateDnsFirewallRequest) GetDeletionProtection() bool {
	if x != nil {
		return x.DeletionProtection
	}
	return false
}

func (x *UpdateDnsFirewallRequest) GetEnabled() bool {
	if x != nil {
		return x.Enabled
	}
	return false
}

func (x *UpdateDnsFirewallRequest) GetResourceConfig() *DnsFirewall_ResourceConfig {
	if x != nil {
		return x.ResourceConfig
	}
	return nil
}

func (x *UpdateDnsFirewallRequest) GetWhitelistFqdns() []string {
	if x != nil {
		return x.WhitelistFqdns
	}
	return nil
}

func (x *UpdateDnsFirewallRequest) GetBlacklistFqdns() []string {
	if x != nil {
		return x.BlacklistFqdns
	}
	return nil
}

type UpdateDnsFirewallMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall that is being updated.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *UpdateDnsFirewallMetadata) Reset() {
	*x = UpdateDnsFirewallMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateDnsFirewallMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateDnsFirewallMetadata) ProtoMessage() {}

func (x *UpdateDnsFirewallMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateDnsFirewallMetadata.ProtoReflect.Descriptor instead.
func (*UpdateDnsFirewallMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{6}
}

func (x *UpdateDnsFirewallMetadata) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

type MoveDnsFirewallRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall to move.
	// To get the DNS firewall ID, make a [DnsFirewallService.List] request.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	// ID of the folder to move the firewall to.
	// To get the folder ID, make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
	DestinationFolderId string `protobuf:"bytes,2,opt,name=destination_folder_id,json=destinationFolderId,proto3" json:"destination_folder_id,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *MoveDnsFirewallRequest) Reset() {
	*x = MoveDnsFirewallRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MoveDnsFirewallRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MoveDnsFirewallRequest) ProtoMessage() {}

func (x *MoveDnsFirewallRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MoveDnsFirewallRequest.ProtoReflect.Descriptor instead.
func (*MoveDnsFirewallRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{7}
}

func (x *MoveDnsFirewallRequest) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

func (x *MoveDnsFirewallRequest) GetDestinationFolderId() string {
	if x != nil {
		return x.DestinationFolderId
	}
	return ""
}

type MoveDnsFirewallMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall that is being moved.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *MoveDnsFirewallMetadata) Reset() {
	*x = MoveDnsFirewallMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MoveDnsFirewallMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MoveDnsFirewallMetadata) ProtoMessage() {}

func (x *MoveDnsFirewallMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MoveDnsFirewallMetadata.ProtoReflect.Descriptor instead.
func (*MoveDnsFirewallMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{8}
}

func (x *MoveDnsFirewallMetadata) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

type DeleteDnsFirewallRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall to delete.
	// To get a DNS firewall ID, make a [DnsFirewallService.List] request.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteDnsFirewallRequest) Reset() {
	*x = DeleteDnsFirewallRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteDnsFirewallRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteDnsFirewallRequest) ProtoMessage() {}

func (x *DeleteDnsFirewallRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteDnsFirewallRequest.ProtoReflect.Descriptor instead.
func (*DeleteDnsFirewallRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{9}
}

func (x *DeleteDnsFirewallRequest) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

type DeleteDnsFirewallMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall that is being deleted.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteDnsFirewallMetadata) Reset() {
	*x = DeleteDnsFirewallMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteDnsFirewallMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteDnsFirewallMetadata) ProtoMessage() {}

func (x *DeleteDnsFirewallMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteDnsFirewallMetadata.ProtoReflect.Descriptor instead.
func (*DeleteDnsFirewallMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{10}
}

func (x *DeleteDnsFirewallMetadata) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

type ListDnsFirewallOperationsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS firewall to list operations for.
	// To get a DNS firewall ID, make a [DnsFirewallService.List] request.
	DnsFirewallId string `protobuf:"bytes,1,opt,name=dns_firewall_id,json=dnsFirewallId,proto3" json:"dns_firewall_id,omitempty"`
	// The maximum number of results per page to return. If the number of available
	// results is larger than [page_size], the service returns a [ListDnsFirewallOperationsResponse.next_page_token]
	// that can be used to get the next page of results in subsequent list requests.
	PageSize int64 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Page token. To get the next page of results, set [page_token] to the
	// [ListDnsFirewallOperationsResponse.next_page_token] returned by a previous list request.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// A filter expression that filters DNS firewalls listed in the response.
	// The expression must specify:
	// 1. The field name. Currently you can use filtering only on the [DnsFirewall.name] field.
	// 2. An `=` operator.
	// 3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
	// Example of a filter: `name=my-dns-firewall`.
	Filter        string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsFirewallOperationsRequest) Reset() {
	*x = ListDnsFirewallOperationsRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsFirewallOperationsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsFirewallOperationsRequest) ProtoMessage() {}

func (x *ListDnsFirewallOperationsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsFirewallOperationsRequest.ProtoReflect.Descriptor instead.
func (*ListDnsFirewallOperationsRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{11}
}

func (x *ListDnsFirewallOperationsRequest) GetDnsFirewallId() string {
	if x != nil {
		return x.DnsFirewallId
	}
	return ""
}

func (x *ListDnsFirewallOperationsRequest) GetPageSize() int64 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListDnsFirewallOperationsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListDnsFirewallOperationsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

type ListDnsFirewallOperationsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// List of operations for the specified DNS firewall.
	Operations []*operation.Operation `protobuf:"bytes,1,rep,name=operations,proto3" json:"operations,omitempty"`
	// Token for getting the next page of the list. If the number of results is greater than
	// the specified [ListDnsFirewallOperationsRequest.page_size], use `next_page_token` as the value
	// for the [ListDnsFirewallOperationsRequest.page_token] parameter in the next list request.
	// Each subsequent page will have its own `next_page_token` to continue paging through the results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsFirewallOperationsResponse) Reset() {
	*x = ListDnsFirewallOperationsResponse{}
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsFirewallOperationsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsFirewallOperationsResponse) ProtoMessage() {}

func (x *ListDnsFirewallOperationsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsFirewallOperationsResponse.ProtoReflect.Descriptor instead.
func (*ListDnsFirewallOperationsResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP(), []int{12}
}

func (x *ListDnsFirewallOperationsResponse) GetOperations() []*operation.Operation {
	if x != nil {
		return x.Operations
	}
	return nil
}

func (x *ListDnsFirewallOperationsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

var File_yandex_cloud_dns_v1_dns_firewall_service_proto protoreflect.FileDescriptor

const file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDesc = "" +
	"\n" +
	".yandex/cloud/dns/v1/dns_firewall_service.proto\x12\x13yandex.cloud.dns.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/dns/v1/dns_firewall.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"E\n" +
	"\x15GetDnsFirewallRequest\x12,\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tB\x04\xe8\xc71\x01R\rdnsFirewallId\"\xb4\x01\n" +
	"\x17ListDnsFirewallsRequest\x12!\n" +
	"\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc71\x01R\bfolderId\x12'\n" +
	"\tpage_size\x18\x02 \x01(\x03B\n" +
	"\xfa\xc71\x06<=1000R\bpageSize\x12)\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\tpageToken\x12\"\n" +
	"\x06filter\x18\x04 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\x06filter\"\x89\x01\n" +
	"\x18ListDnsFirewallsResponse\x12E\n" +
	"\rdns_firewalls\x18\x01 \x03(\v2 .yandex.cloud.dns.v1.DnsFirewallR\fdnsFirewalls\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xa7\x05\n" +
	"\x18CreateDnsFirewallRequest\x12)\n" +
	"\tfolder_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\bfolderId\x128\n" +
	"\x04name\x18\x02 \x01(\tB$\xf2\xc71 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?R\x04name\x12+\n" +
	"\vdescription\x18\x03 \x01(\tB\t\x8a\xc81\x05<=256R\vdescription\x12\x96\x01\n" +
	"\x06labels\x18\x04 \x03(\v29.yandex.cloud.dns.v1.CreateDnsFirewallRequest.LabelsEntryBC\xf2\xc71\x0f[-_./\\@0-9a-z]*\x82\xc81\x04<=64\x8a\xc81\x04<=63\xb2\xc81\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x041-63R\x06labels\x12/\n" +
	"\x13deletion_protection\x18\x05 \x01(\bR\x12deletionProtection\x12\x18\n" +
	"\aenabled\x18\x06 \x01(\bR\aenabled\x12X\n" +
	"\x0fresource_config\x18\a \x01(\v2/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfigR\x0eresourceConfig\x12?\n" +
	"\x0fwhitelist_fqdns\x18\b \x03(\tB\x16\x82\xc81\x05<=255\x8a\xc81\x05<=255\x90\xc81\x01R\x0ewhitelistFqdns\x12?\n" +
	"\x0fblacklist_fqdns\x18\t \x03(\tB\x16\x82\xc81\x05<=255\x8a\xc81\x05<=255\x90\xc81\x01R\x0eblacklistFqdns\x1a9\n" +
	"\vLabelsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\"C\n" +
	"\x19CreateDnsFirewallMetadata\x12&\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tR\rdnsFirewallId\"\xe7\x05\n" +
	"\x18UpdateDnsFirewallRequest\x12,\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tB\x04\xe8\xc71\x01R\rdnsFirewallId\x12;\n" +
	"\vupdate_mask\x18\x02 \x01(\v2\x1a.google.protobuf.FieldMaskR\n" +
	"updateMask\x128\n" +
	"\x04name\x18\x03 \x01(\tB$\xf2\xc71 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?R\x04name\x12+\n" +
	"\vdescription\x18\x04 \x01(\tB\t\x8a\xc81\x05<=256R\vdescription\x12\x96\x01\n" +
	"\x06labels\x18\x05 \x03(\v29.yandex.cloud.dns.v1.UpdateDnsFirewallRequest.LabelsEntryBC\xf2\xc71\x0f[-_./\\@0-9a-z]*\x82\xc81\x04<=64\x8a\xc81\x04<=63\xb2\xc81\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x041-63R\x06labels\x12/\n" +
	"\x13deletion_protection\x18\x06 \x01(\bR\x12deletionProtection\x12\x18\n" +
	"\aenabled\x18\a \x01(\bR\aenabled\x12X\n" +
	"\x0fresource_config\x18\b \x01(\v2/.yandex.cloud.dns.v1.DnsFirewall.ResourceConfigR\x0eresourceConfig\x12?\n" +
	"\x0fwhitelist_fqdns\x18\t \x03(\tB\x16\x82\xc81\x05<=255\x8a\xc81\x05<=255\x90\xc81\x01R\x0ewhitelistFqdns\x12?\n" +
	"\x0fblacklist_fqdns\x18\n" +
	" \x03(\tB\x16\x82\xc81\x05<=255\x8a\xc81\x05<=255\x90\xc81\x01R\x0eblacklistFqdns\x1a9\n" +
	"\vLabelsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\"C\n" +
	"\x19UpdateDnsFirewallMetadata\x12&\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tR\rdnsFirewallId\"\x91\x01\n" +
	"\x16MoveDnsFirewallRequest\x125\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tB\r\xe8\xc71\x01\x8a\xc81\x05<=255R\rdnsFirewallId\x12@\n" +
	"\x15destination_folder_id\x18\x02 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\x13destinationFolderId\"A\n" +
	"\x17MoveDnsFirewallMetadata\x12&\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tR\rdnsFirewallId\"Q\n" +
	"\x18DeleteDnsFirewallRequest\x125\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tB\r\xe8\xc71\x01\x8a\xc81\x05<=255R\rdnsFirewallId\"C\n" +
	"\x19DeleteDnsFirewallMetadata\x12&\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tR\rdnsFirewallId\"\xcd\x01\n" +
	" ListDnsFirewallOperationsRequest\x121\n" +
	"\x0fdns_firewall_id\x18\x01 \x01(\tB\t\x8a\xc81\x05<=255R\rdnsFirewallId\x12'\n" +
	"\tpage_size\x18\x02 \x01(\x03B\n" +
	"\xfa\xc71\x060-1000R\bpageSize\x12)\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\tpageToken\x12\"\n" +
	"\x06filter\x18\x04 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\x06filter\"\x8e\x01\n" +
	"!ListDnsFirewallOperationsResponse\x12A\n" +
	"\n" +
	"operations\x18\x01 \x03(\v2!.yandex.cloud.operation.OperationR\n" +
	"operations\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xaf\x0e\n" +
	"\x12DnsFirewallService\x12\x80\x01\n" +
	"\x03Get\x12*.yandex.cloud.dns.v1.GetDnsFirewallRequest\x1a .yandex.cloud.dns.v1.DnsFirewall\"+\x82\xd3\xe4\x93\x02%\x12#/dns/v1/firewalls/{dns_firewall_id}\x12~\n" +
	"\x04List\x12,.yandex.cloud.dns.v1.ListDnsFirewallsRequest\x1a-.yandex.cloud.dns.v1.ListDnsFirewallsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/dns/v1/firewalls\x12\xa4\x01\n" +
	"\x06Create\x12-.yandex.cloud.dns.v1.CreateDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*(\n" +
	"\x19CreateDnsFirewallMetadata\x12\vDnsFirewall\x82\xd3\xe4\x93\x02\x16:\x01*\"\x11/dns/v1/firewalls\x12\xb6\x01\n" +
	"\x06Update\x12-.yandex.cloud.dns.v1.UpdateDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*(\n" +
	"\x19UpdateDnsFirewallMetadata\x12\vDnsFirewall\x82\xd3\xe4\x93\x02(:\x01*2#/dns/v1/firewalls/{dns_firewall_id}\x12\xb5\x01\n" +
	"\x04Move\x12+.yandex.cloud.dns.v1.MoveDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*&\n" +
	"\x17MoveDnsFirewallMetadata\x12\vDnsFirewall\x82\xd3\xe4\x93\x02-:\x01*\"(/dns/v1/firewalls/{dns_firewall_id}:move\x12\xbd\x01\n" +
	"\x06Delete\x12-.yandex.cloud.dns.v1.DeleteDnsFirewallRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*2\n" +
	"\x19DeleteDnsFirewallMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/dns/v1/firewalls/{dns_firewall_id}\x12\xb7\x01\n" +
	"\x0eListOperations\x125.yandex.cloud.dns.v1.ListDnsFirewallOperationsRequest\x1a6.yandex.cloud.dns.v1.ListDnsFirewallOperationsResponse\"6\x82\xd3\xe4\x93\x020\x12./dns/v1/firewalls/{dns_firewall_id}/operations\x12\xb1\x01\n" +
	"\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\":\x82\xd3\xe4\x93\x024\x122/dns/v1/firewalls/{resource_id}:listAccessBindings\x12\xe0\x01\n" +
	"\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*9\n" +
	" access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x026:\x01*\"1/dns/v1/firewalls/{resource_id}:setAccessBindings\x12\xec\x01\n" +
	"\x14UpdateAccessBindings\x120.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*<\n" +
	"#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x029:\x01*\"4/dns/v1/firewalls/{resource_id}:updateAccessBindingsBV\n" +
	"\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3"

var (
	file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescOnce sync.Once
	file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescData []byte
)

func file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescGZIP() []byte {
	file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDesc), len(file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDesc)))
	})
	return file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDescData
}

var file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes = make([]protoimpl.MessageInfo, 15)
var file_yandex_cloud_dns_v1_dns_firewall_service_proto_goTypes = []any{
	(*GetDnsFirewallRequest)(nil),             // 0: yandex.cloud.dns.v1.GetDnsFirewallRequest
	(*ListDnsFirewallsRequest)(nil),           // 1: yandex.cloud.dns.v1.ListDnsFirewallsRequest
	(*ListDnsFirewallsResponse)(nil),          // 2: yandex.cloud.dns.v1.ListDnsFirewallsResponse
	(*CreateDnsFirewallRequest)(nil),          // 3: yandex.cloud.dns.v1.CreateDnsFirewallRequest
	(*CreateDnsFirewallMetadata)(nil),         // 4: yandex.cloud.dns.v1.CreateDnsFirewallMetadata
	(*UpdateDnsFirewallRequest)(nil),          // 5: yandex.cloud.dns.v1.UpdateDnsFirewallRequest
	(*UpdateDnsFirewallMetadata)(nil),         // 6: yandex.cloud.dns.v1.UpdateDnsFirewallMetadata
	(*MoveDnsFirewallRequest)(nil),            // 7: yandex.cloud.dns.v1.MoveDnsFirewallRequest
	(*MoveDnsFirewallMetadata)(nil),           // 8: yandex.cloud.dns.v1.MoveDnsFirewallMetadata
	(*DeleteDnsFirewallRequest)(nil),          // 9: yandex.cloud.dns.v1.DeleteDnsFirewallRequest
	(*DeleteDnsFirewallMetadata)(nil),         // 10: yandex.cloud.dns.v1.DeleteDnsFirewallMetadata
	(*ListDnsFirewallOperationsRequest)(nil),  // 11: yandex.cloud.dns.v1.ListDnsFirewallOperationsRequest
	(*ListDnsFirewallOperationsResponse)(nil), // 12: yandex.cloud.dns.v1.ListDnsFirewallOperationsResponse
	nil,                                        // 13: yandex.cloud.dns.v1.CreateDnsFirewallRequest.LabelsEntry
	nil,                                        // 14: yandex.cloud.dns.v1.UpdateDnsFirewallRequest.LabelsEntry
	(*DnsFirewall)(nil),                        // 15: yandex.cloud.dns.v1.DnsFirewall
	(*DnsFirewall_ResourceConfig)(nil),         // 16: yandex.cloud.dns.v1.DnsFirewall.ResourceConfig
	(*fieldmaskpb.FieldMask)(nil),              // 17: google.protobuf.FieldMask
	(*operation.Operation)(nil),                // 18: yandex.cloud.operation.Operation
	(*access.ListAccessBindingsRequest)(nil),   // 19: yandex.cloud.access.ListAccessBindingsRequest
	(*access.SetAccessBindingsRequest)(nil),    // 20: yandex.cloud.access.SetAccessBindingsRequest
	(*access.UpdateAccessBindingsRequest)(nil), // 21: yandex.cloud.access.UpdateAccessBindingsRequest
	(*access.ListAccessBindingsResponse)(nil),  // 22: yandex.cloud.access.ListAccessBindingsResponse
}
var file_yandex_cloud_dns_v1_dns_firewall_service_proto_depIdxs = []int32{
	15, // 0: yandex.cloud.dns.v1.ListDnsFirewallsResponse.dns_firewalls:type_name -> yandex.cloud.dns.v1.DnsFirewall
	13, // 1: yandex.cloud.dns.v1.CreateDnsFirewallRequest.labels:type_name -> yandex.cloud.dns.v1.CreateDnsFirewallRequest.LabelsEntry
	16, // 2: yandex.cloud.dns.v1.CreateDnsFirewallRequest.resource_config:type_name -> yandex.cloud.dns.v1.DnsFirewall.ResourceConfig
	17, // 3: yandex.cloud.dns.v1.UpdateDnsFirewallRequest.update_mask:type_name -> google.protobuf.FieldMask
	14, // 4: yandex.cloud.dns.v1.UpdateDnsFirewallRequest.labels:type_name -> yandex.cloud.dns.v1.UpdateDnsFirewallRequest.LabelsEntry
	16, // 5: yandex.cloud.dns.v1.UpdateDnsFirewallRequest.resource_config:type_name -> yandex.cloud.dns.v1.DnsFirewall.ResourceConfig
	18, // 6: yandex.cloud.dns.v1.ListDnsFirewallOperationsResponse.operations:type_name -> yandex.cloud.operation.Operation
	0,  // 7: yandex.cloud.dns.v1.DnsFirewallService.Get:input_type -> yandex.cloud.dns.v1.GetDnsFirewallRequest
	1,  // 8: yandex.cloud.dns.v1.DnsFirewallService.List:input_type -> yandex.cloud.dns.v1.ListDnsFirewallsRequest
	3,  // 9: yandex.cloud.dns.v1.DnsFirewallService.Create:input_type -> yandex.cloud.dns.v1.CreateDnsFirewallRequest
	5,  // 10: yandex.cloud.dns.v1.DnsFirewallService.Update:input_type -> yandex.cloud.dns.v1.UpdateDnsFirewallRequest
	7,  // 11: yandex.cloud.dns.v1.DnsFirewallService.Move:input_type -> yandex.cloud.dns.v1.MoveDnsFirewallRequest
	9,  // 12: yandex.cloud.dns.v1.DnsFirewallService.Delete:input_type -> yandex.cloud.dns.v1.DeleteDnsFirewallRequest
	11, // 13: yandex.cloud.dns.v1.DnsFirewallService.ListOperations:input_type -> yandex.cloud.dns.v1.ListDnsFirewallOperationsRequest
	19, // 14: yandex.cloud.dns.v1.DnsFirewallService.ListAccessBindings:input_type -> yandex.cloud.access.ListAccessBindingsRequest
	20, // 15: yandex.cloud.dns.v1.DnsFirewallService.SetAccessBindings:input_type -> yandex.cloud.access.SetAccessBindingsRequest
	21, // 16: yandex.cloud.dns.v1.DnsFirewallService.UpdateAccessBindings:input_type -> yandex.cloud.access.UpdateAccessBindingsRequest
	15, // 17: yandex.cloud.dns.v1.DnsFirewallService.Get:output_type -> yandex.cloud.dns.v1.DnsFirewall
	2,  // 18: yandex.cloud.dns.v1.DnsFirewallService.List:output_type -> yandex.cloud.dns.v1.ListDnsFirewallsResponse
	18, // 19: yandex.cloud.dns.v1.DnsFirewallService.Create:output_type -> yandex.cloud.operation.Operation
	18, // 20: yandex.cloud.dns.v1.DnsFirewallService.Update:output_type -> yandex.cloud.operation.Operation
	18, // 21: yandex.cloud.dns.v1.DnsFirewallService.Move:output_type -> yandex.cloud.operation.Operation
	18, // 22: yandex.cloud.dns.v1.DnsFirewallService.Delete:output_type -> yandex.cloud.operation.Operation
	12, // 23: yandex.cloud.dns.v1.DnsFirewallService.ListOperations:output_type -> yandex.cloud.dns.v1.ListDnsFirewallOperationsResponse
	22, // 24: yandex.cloud.dns.v1.DnsFirewallService.ListAccessBindings:output_type -> yandex.cloud.access.ListAccessBindingsResponse
	18, // 25: yandex.cloud.dns.v1.DnsFirewallService.SetAccessBindings:output_type -> yandex.cloud.operation.Operation
	18, // 26: yandex.cloud.dns.v1.DnsFirewallService.UpdateAccessBindings:output_type -> yandex.cloud.operation.Operation
	17, // [17:27] is the sub-list for method output_type
	7,  // [7:17] is the sub-list for method input_type
	7,  // [7:7] is the sub-list for extension type_name
	7,  // [7:7] is the sub-list for extension extendee
	0,  // [0:7] is the sub-list for field type_name
}

func init() { file_yandex_cloud_dns_v1_dns_firewall_service_proto_init() }
func file_yandex_cloud_dns_v1_dns_firewall_service_proto_init() {
	if File_yandex_cloud_dns_v1_dns_firewall_service_proto != nil {
		return
	}
	file_yandex_cloud_dns_v1_dns_firewall_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDesc), len(file_yandex_cloud_dns_v1_dns_firewall_service_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   15,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_yandex_cloud_dns_v1_dns_firewall_service_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_dns_v1_dns_firewall_service_proto_depIdxs,
		MessageInfos:      file_yandex_cloud_dns_v1_dns_firewall_service_proto_msgTypes,
	}.Build()
	File_yandex_cloud_dns_v1_dns_firewall_service_proto = out.File
	file_yandex_cloud_dns_v1_dns_firewall_service_proto_goTypes = nil
	file_yandex_cloud_dns_v1_dns_firewall_service_proto_depIdxs = nil
}
