// Code generated by sdkgen-v2. DO NOT EDIT.
package endpoints

import (
	"google.golang.org/protobuf/reflect/protoreflect"
)

var DynamicEndpoints = map[protoreflect.FullName]string{
	protoreflect.FullName("speechkit.stt.v3"):                                                                "ai-stt",
	protoreflect.FullName("speechkit.tts.v3"):                                                                "ai-tts",
	protoreflect.FullName("yandex.cloud.ai.assistants.v1"):                                                   "ai-assistants",
	protoreflect.FullName("yandex.cloud.ai.dataset.v1"):                                                      "ai-fomo-dataset",
	protoreflect.FullName("yandex.cloud.ai.files.v1"):                                                        "ai-files",
	protoreflect.FullName("yandex.cloud.ai.foundation_models.v1"):                                            "ai-foundatation-models",
	protoreflect.FullName("yandex.cloud.ai.llm.v1alpha"):                                                     "ai-llm",
	protoreflect.FullName("yandex.cloud.ai.ocr.v1"):                                                          "ai-ocr",
	protoreflect.FullName("yandex.cloud.ai.stt.v2"):                                                          "ai-stt",
	protoreflect.FullName("yandex.cloud.ai.translate.v2"):                                                    "ai-translate",
	protoreflect.FullName("yandex.cloud.ai.tts.v1"):                                                          "ai-tts",
	protoreflect.FullName("yandex.cloud.ai.tuning.v1"):                                                       "ai-fomo-tuning",
	protoreflect.FullName("yandex.cloud.ai.vision.v1"):                                                       "ai-vision",
	protoreflect.FullName("yandex.cloud.ai.vision.v2"):                                                       "ai-vision",
	protoreflect.FullName("yandex.cloud.airflow.v1"):                                                         "managed-airflow",
	protoreflect.FullName("yandex.cloud.apploadbalancer.v1"):                                                 "alb",
	protoreflect.FullName("yandex.cloud.audittrails.v1"):                                                     "audittrails",
	protoreflect.FullName("yandex.cloud.backup.agent.v1"):                                                    "backup",
	protoreflect.FullName("yandex.cloud.backup.v1"):                                                          "backup",
	protoreflect.FullName("yandex.cloud.baremetal.v1alpha"):                                                  "baremetal",
	protoreflect.FullName("yandex.cloud.billing.v1"):                                                         "billing",
	protoreflect.FullName("yandex.cloud.cdn.v1"):                                                             "cdn",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.CertificateContentService"):                    "certificate-manager-data",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.CertificateService"):                           "certificate-manager",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.privateca.PolicyService"):                      "certificate-manager-private-ca",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.privateca.PrivateCaCertificateContentService"): "certificate-manager-private-ca-data",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.privateca.PrivateCaCertificateService"):        "certificate-manager-private-ca",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.privateca.PrivateCaContentService"):            "certificate-manager-private-ca-data",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.privateca.PrivateCaService"):                   "certificate-manager-private-ca",
	protoreflect.FullName("yandex.cloud.certificatemanager.v1.privateca.TemplateService"):                    "certificate-manager-private-ca",
	protoreflect.FullName("yandex.cloud.cic.v1"):                                                             "cic",
	protoreflect.FullName("yandex.cloud.cloudapps.workload.v1"):                                              "cloudapps",
	protoreflect.FullName("yandex.cloud.clouddesktop.v1.api"):                                                "clouddesktops",
	protoreflect.FullName("yandex.cloud.cloudregistry.v1"):                                                   "cloud-registry",
	protoreflect.FullName("yandex.cloud.cloudrouter.v1"):                                                     "cloudrouter",
	protoreflect.FullName("yandex.cloud.compute.v1"):                                                         "compute",
	protoreflect.FullName("yandex.cloud.compute.v1.instancegroup"):                                           "compute",
	protoreflect.FullName("yandex.cloud.connectionmanager.v1"):                                               "connection-manager",
	protoreflect.FullName("yandex.cloud.containerregistry.v1"):                                               "container-registry",
	protoreflect.FullName("yandex.cloud.datacatalog.v1"):                                                     "datacatalog",
	protoreflect.FullName("yandex.cloud.dataproc.manager.v1"):                                                "dataproc",
	protoreflect.FullName("yandex.cloud.dataproc.v1"):                                                        "dataproc",
	protoreflect.FullName("yandex.cloud.datasphere.v1"):                                                      "datasphere",
	protoreflect.FullName("yandex.cloud.datasphere.v2"):                                                      "datasphere",
	protoreflect.FullName("yandex.cloud.datatransfer.v1"):                                                    "datatransfer",
	protoreflect.FullName("yandex.cloud.devtools.ycvc.v1"):                                                   "ycvc",
	protoreflect.FullName("yandex.cloud.dns.v1"):                                                             "dns",
	protoreflect.FullName("yandex.cloud.gitlab.v1"):                                                          "gitlab",
	protoreflect.FullName("yandex.cloud.iam.v1"):                                                             "iam",
	protoreflect.FullName("yandex.cloud.iot.broker.v1.BrokerDataService"):                                    "broker-data",
	protoreflect.FullName("yandex.cloud.iot.broker.v1.BrokerService"):                                        "iotbroker",
	protoreflect.FullName("yandex.cloud.iot.devices.v1.DeviceDataService"):                                   "broker-data",
	protoreflect.FullName("yandex.cloud.iot.devices.v1.DeviceService"):                                       "iotbroker",
	protoreflect.FullName("yandex.cloud.iot.devices.v1.RegistryDataService"):                                 "broker-data",
	protoreflect.FullName("yandex.cloud.iot.devices.v1.RegistryService"):                                     "iotbroker",
	protoreflect.FullName("yandex.cloud.k8s.marketplace.v1"):                                                 "managed-kubernetes",
	protoreflect.FullName("yandex.cloud.k8s.v1"):                                                             "managed-kubernetes",
	protoreflect.FullName("yandex.cloud.kms.v1.SymmetricCryptoService"):                                      "kms-crypto",
	protoreflect.FullName("yandex.cloud.kms.v1.SymmetricKeyService"):                                         "kms",
	protoreflect.FullName("yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionCryptoService"):      "kms-crypto",
	protoreflect.FullName("yandex.cloud.kms.v1.asymmetricencryption.AsymmetricEncryptionKeyService"):         "kms",
	protoreflect.FullName("yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureCryptoService"):        "kms-crypto",
	protoreflect.FullName("yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService"):           "kms",
	protoreflect.FullName("yandex.cloud.loadbalancer.v1"):                                                    "load-balancer",
	protoreflect.FullName("yandex.cloud.loadbalancer.v1alpha"):                                               "load-balancer",
	protoreflect.FullName("yandex.cloud.loadtesting.agent.v1"):                                               "loadtesting",
	protoreflect.FullName("yandex.cloud.loadtesting.api.v1"):                                                 "loadtesting",
	protoreflect.FullName("yandex.cloud.loadtesting.v1"):                                                     "loadtesting",
	protoreflect.FullName("yandex.cloud.locator.v1"):                                                         "locator",
	protoreflect.FullName("yandex.cloud.lockbox.v1.PayloadService"):                                          "lockbox-payload",
	protoreflect.FullName("yandex.cloud.lockbox.v1.SecretService"):                                           "lockbox",
	protoreflect.FullName("yandex.cloud.logging.v1"):                                                         "logging",
	protoreflect.FullName("yandex.cloud.marketplace.licensemanager.saas.v1"):                                 "marketplace",
	protoreflect.FullName("yandex.cloud.marketplace.licensemanager.v1"):                                      "marketplace",
	protoreflect.FullName("yandex.cloud.marketplace.metering.v1"):                                            "marketplace",
	protoreflect.FullName("yandex.cloud.marketplace.pim.v1.saas"):                                            "marketplace",
	protoreflect.FullName("yandex.cloud.marketplace.stacklandlicenseapi.v1"):                                 "marketplace",
	protoreflect.FullName("yandex.cloud.marketplace.v1.metering"):                                            "marketplace",
	protoreflect.FullName("yandex.cloud.mdb.clickhouse.v1"):                                                  "managed-clickhouse",
	protoreflect.FullName("yandex.cloud.mdb.elasticsearch.v1"):                                               "managed-elasticsearch",
	protoreflect.FullName("yandex.cloud.mdb.greenplum.v1"):                                                   "managed-greenplum",
	protoreflect.FullName("yandex.cloud.mdb.kafka.v1"):                                                       "managed-kafka",
	protoreflect.FullName("yandex.cloud.mdb.mongodb.v1"):                                                     "managed-mongodb",
	protoreflect.FullName("yandex.cloud.mdb.mysql.v1"):                                                       "managed-mysql",
	protoreflect.FullName("yandex.cloud.mdb.mysql.v1alpha"):                                                  "managed-mysql",
	protoreflect.FullName("yandex.cloud.mdb.opensearch.v1"):                                                  "managed-opensearch",
	protoreflect.FullName("yandex.cloud.mdb.postgresql.v1"):                                                  "managed-postgresql",
	protoreflect.FullName("yandex.cloud.mdb.redis.v1"):                                                       "managed-redis",
	protoreflect.FullName("yandex.cloud.mdb.spqr.v1"):                                                        "managed-spqr",
	protoreflect.FullName("yandex.cloud.metastore.v1"):                                                       "managed-metastore",
	protoreflect.FullName("yandex.cloud.monitoring.v1alpha"):                                                 "monitoring",
	protoreflect.FullName("yandex.cloud.monitoring.v2"):                                                      "monitoring",
	protoreflect.FullName("yandex.cloud.monitoring.v3"):                                                      "monitoring",
	protoreflect.FullName("yandex.cloud.operation"):                                                          "operation",
	protoreflect.FullName("yandex.cloud.organizationmanager.v1"):                                             "organization-manager",
	protoreflect.FullName("yandex.cloud.quotamanager.v1"):                                                    "quota-manager",
	protoreflect.FullName("yandex.cloud.resourcemanager.v1"):                                                 "resource-manager",
	protoreflect.FullName("yandex.cloud.searchapi.v2"):                                                       "searchapi",
	protoreflect.FullName("yandex.cloud.securitydeck.alerts.v1"):                                             "alert-sink",
	protoreflect.FullName("yandex.cloud.serverless.apigateway.v1"):                                           "serverless-apigateway",
	protoreflect.FullName("yandex.cloud.serverless.apigateway.websocket.v1"):                                 "serverless-gateway-connections",
	protoreflect.FullName("yandex.cloud.serverless.containers.v1"):                                           "serverless-containers",
	protoreflect.FullName("yandex.cloud.serverless.eventrouter.v1"):                                          "serverless-eventrouter",
	protoreflect.FullName("yandex.cloud.serverless.functions.v1"):                                            "serverless-functions",
	protoreflect.FullName("yandex.cloud.serverless.mcpgateway.v1"):                                           "mcp-gateway",
	protoreflect.FullName("yandex.cloud.serverless.mdbproxy.v1"):                                             "mdbproxy",
	protoreflect.FullName("yandex.cloud.serverless.triggers.v1"):                                             "serverless-triggers",
	protoreflect.FullName("yandex.cloud.serverless.workflows.v1"):                                            "serverless-workflows",
	protoreflect.FullName("yandex.cloud.servicename.v1"):                                                     "servicename",
	protoreflect.FullName("yandex.cloud.smartcaptcha.v1"):                                                    "smart-captcha",
	protoreflect.FullName("yandex.cloud.smartwebsecurity.v1"):                                                "smart-web-security",
	protoreflect.FullName("yandex.cloud.spark.v1"):                                                           "managed-spark",
	protoreflect.FullName("yandex.cloud.speechsense.v1"):                                                     "speechsense",
	protoreflect.FullName("yandex.cloud.storage.v1"):                                                         "storage-api",
	protoreflect.FullName("yandex.cloud.trino.v1"):                                                           "managed-trino",
	protoreflect.FullName("yandex.cloud.video.v1"):                                                           "video",
	protoreflect.FullName("yandex.cloud.vpc.v1"):                                                             "vpc",
	protoreflect.FullName("yandex.cloud.ydb.v1"):                                                             "ydb",
	protoreflect.FullName("yandex.cloud.ytsaurus.v1"):                                                        "managed-ytsaurus",
}
