// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/iam/v1/refresh_token_service.proto

package iam

import (
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud"
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud/api"
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type RevokeRefreshTokenMetadata struct {
	state     protoimpl.MessageState `protogen:"open.v1"`
	SubjectId string                 `protobuf:"bytes,1,opt,name=subject_id,json=subjectId,proto3" json:"subject_id,omitempty"`
	// Id of revoked Refresh Tokens.
	RefreshTokenIds []string `protobuf:"bytes,2,rep,name=refresh_token_ids,json=refreshTokenIds,proto3" json:"refresh_token_ids,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *RevokeRefreshTokenMetadata) Reset() {
	*x = RevokeRefreshTokenMetadata{}
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeRefreshTokenMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeRefreshTokenMetadata) ProtoMessage() {}

func (x *RevokeRefreshTokenMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeRefreshTokenMetadata.ProtoReflect.Descriptor instead.
func (*RevokeRefreshTokenMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP(), []int{0}
}

func (x *RevokeRefreshTokenMetadata) GetSubjectId() string {
	if x != nil {
		return x.SubjectId
	}
	return ""
}

func (x *RevokeRefreshTokenMetadata) GetRefreshTokenIds() []string {
	if x != nil {
		return x.RefreshTokenIds
	}
	return nil
}

type ListRefreshTokensRequest struct {
	state     protoimpl.MessageState `protogen:"open.v1"`
	SubjectId string                 `protobuf:"bytes,1,opt,name=subject_id,json=subjectId,proto3" json:"subject_id,omitempty"`
	// The maximum number of results per page to return. If the number of available
	// results is larger than [page_size],
	// the service returns a [ListRefreshTokensResponse.next_page_token]
	// that can be used to get the next page of results in subsequent list requests.
	// Default value: 100.
	PageSize int64 `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Page token. To get the next page of results, set [page_token]
	// to the [ListRefreshTokensResponse.next_page_token]
	// returned by a previous list request.
	PageToken string `protobuf:"bytes,5,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// A filter expression that filters refresh tokens listed in the response.
	//
	// The expression must specify:
	// 1. The field name. Currently you can use filtering only on [RefreshToken.client_instance_info], [RefreshToken.client_id] or [RefreshToken.protection_level] fields.
	// 2. The operator. An `=` operator can be used for all fields. An 'IN' operator can be used for [RefreshToken.protection_level].
	// 3. The value. The value must be in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-zA-Z][_-a-zA-Z0-9]{1,61}[a-z0-9]`.
	// Example of a filter: `client_instance_info="clientInstanceInfo" AND protection_level IN ("INSECURE_KEY_DPOP", "SECURE_KEY_DPOP")`.
	Filter        string `protobuf:"bytes,6,opt,name=filter,proto3" json:"filter,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListRefreshTokensRequest) Reset() {
	*x = ListRefreshTokensRequest{}
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListRefreshTokensRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListRefreshTokensRequest) ProtoMessage() {}

func (x *ListRefreshTokensRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListRefreshTokensRequest.ProtoReflect.Descriptor instead.
func (*ListRefreshTokensRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP(), []int{1}
}

func (x *ListRefreshTokensRequest) GetSubjectId() string {
	if x != nil {
		return x.SubjectId
	}
	return ""
}

func (x *ListRefreshTokensRequest) GetPageSize() int64 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListRefreshTokensRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListRefreshTokensRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

type ListRefreshTokensResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// List of Refresh Tokens
	RefreshTokens []*RefreshToken `protobuf:"bytes,1,rep,name=refresh_tokens,json=refreshTokens,proto3" json:"refresh_tokens,omitempty"`
	// This token allows you to get the next page of results for list requests. If the number of results
	// is larger than [ListRefreshTokensForSubjectRequest.page_size], use
	// the [next_page_token] as the value
	// for the [ListRefreshTokensForSubjectRequest.page_token] query parameter
	// in the next list request. Each subsequent list request will have its own
	// [next_page_token] to continue paging through the results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListRefreshTokensResponse) Reset() {
	*x = ListRefreshTokensResponse{}
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListRefreshTokensResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListRefreshTokensResponse) ProtoMessage() {}

func (x *ListRefreshTokensResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListRefreshTokensResponse.ProtoReflect.Descriptor instead.
func (*ListRefreshTokensResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP(), []int{2}
}

func (x *ListRefreshTokensResponse) GetRefreshTokens() []*RefreshToken {
	if x != nil {
		return x.RefreshTokens
	}
	return nil
}

func (x *ListRefreshTokensResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

// Revoke Refresh Token request.
// If none of the parameters refresh_token_id, refresh_token, or revoke_filter are provided, all Refresh Tokens for the current subject will be revoked.
type RevokeRefreshTokenRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Filter:
	//
	//	*RevokeRefreshTokenRequest_RefreshTokenId
	//	*RevokeRefreshTokenRequest_RefreshToken
	//	*RevokeRefreshTokenRequest_RevokeFilter
	Filter        isRevokeRefreshTokenRequest_Filter `protobuf_oneof:"filter"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeRefreshTokenRequest) Reset() {
	*x = RevokeRefreshTokenRequest{}
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeRefreshTokenRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeRefreshTokenRequest) ProtoMessage() {}

func (x *RevokeRefreshTokenRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeRefreshTokenRequest.ProtoReflect.Descriptor instead.
func (*RevokeRefreshTokenRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP(), []int{3}
}

func (x *RevokeRefreshTokenRequest) GetFilter() isRevokeRefreshTokenRequest_Filter {
	if x != nil {
		return x.Filter
	}
	return nil
}

func (x *RevokeRefreshTokenRequest) GetRefreshTokenId() string {
	if x != nil {
		if x, ok := x.Filter.(*RevokeRefreshTokenRequest_RefreshTokenId); ok {
			return x.RefreshTokenId
		}
	}
	return ""
}

func (x *RevokeRefreshTokenRequest) GetRefreshToken() string {
	if x != nil {
		if x, ok := x.Filter.(*RevokeRefreshTokenRequest_RefreshToken); ok {
			return x.RefreshToken
		}
	}
	return ""
}

func (x *RevokeRefreshTokenRequest) GetRevokeFilter() *RevokeFilter {
	if x != nil {
		if x, ok := x.Filter.(*RevokeRefreshTokenRequest_RevokeFilter); ok {
			return x.RevokeFilter
		}
	}
	return nil
}

type isRevokeRefreshTokenRequest_Filter interface {
	isRevokeRefreshTokenRequest_Filter()
}

type RevokeRefreshTokenRequest_RefreshTokenId struct {
	// Identifier of the Refresh Token to be revoked.
	RefreshTokenId string `protobuf:"bytes,1,opt,name=refresh_token_id,json=refreshTokenId,proto3,oneof"`
}

type RevokeRefreshTokenRequest_RefreshToken struct {
	// The Refresh Token to be revoked.
	RefreshToken string `protobuf:"bytes,2,opt,name=refresh_token,json=refreshToken,proto3,oneof"`
}

type RevokeRefreshTokenRequest_RevokeFilter struct {
	// The filter for revoking Refresh Token
	RevokeFilter *RevokeFilter `protobuf:"bytes,3,opt,name=revoke_filter,json=revokeFilter,proto3,oneof"`
}

func (*RevokeRefreshTokenRequest_RefreshTokenId) isRevokeRefreshTokenRequest_Filter() {}

func (*RevokeRefreshTokenRequest_RefreshToken) isRevokeRefreshTokenRequest_Filter() {}

func (*RevokeRefreshTokenRequest_RevokeFilter) isRevokeRefreshTokenRequest_Filter() {}

// The Filter object allows filtering Refresh Tokens that will be revoked.
// It contains three optional fields.
// When multiple fields are provided, they are combined using a logical AND operation.
type RevokeFilter struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// The OAuth client identifier for which the Refresh Token was issued.
	ClientId string `protobuf:"bytes,2,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
	// The subject identifier for whom the Refresh Token was issued.
	// If not specified, it defaults to the subject that made the request.
	SubjectId string `protobuf:"bytes,3,opt,name=subject_id,json=subjectId,proto3" json:"subject_id,omitempty"`
	// Information about the app for which the Refresh Token was issued.
	ClientInstanceInfo string `protobuf:"bytes,4,opt,name=client_instance_info,json=clientInstanceInfo,proto3" json:"client_instance_info,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *RevokeFilter) Reset() {
	*x = RevokeFilter{}
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeFilter) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeFilter) ProtoMessage() {}

func (x *RevokeFilter) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeFilter.ProtoReflect.Descriptor instead.
func (*RevokeFilter) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP(), []int{4}
}

func (x *RevokeFilter) GetClientId() string {
	if x != nil {
		return x.ClientId
	}
	return ""
}

func (x *RevokeFilter) GetSubjectId() string {
	if x != nil {
		return x.SubjectId
	}
	return ""
}

func (x *RevokeFilter) GetClientInstanceInfo() string {
	if x != nil {
		return x.ClientInstanceInfo
	}
	return ""
}

type RevokeRefreshTokenResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Id of revoked Refresh Tokens.
	RefreshTokenIds []string `protobuf:"bytes,1,rep,name=refresh_token_ids,json=refreshTokenIds,proto3" json:"refresh_token_ids,omitempty"`
	unknownFields   protoimpl.UnknownFields
	sizeCache       protoimpl.SizeCache
}

func (x *RevokeRefreshTokenResponse) Reset() {
	*x = RevokeRefreshTokenResponse{}
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeRefreshTokenResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeRefreshTokenResponse) ProtoMessage() {}

func (x *RevokeRefreshTokenResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeRefreshTokenResponse.ProtoReflect.Descriptor instead.
func (*RevokeRefreshTokenResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP(), []int{5}
}

func (x *RevokeRefreshTokenResponse) GetRefreshTokenIds() []string {
	if x != nil {
		return x.RefreshTokenIds
	}
	return nil
}

var File_yandex_cloud_iam_v1_refresh_token_service_proto protoreflect.FileDescriptor

const file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDesc = "" +
	"\n" +
	"/yandex/cloud/iam/v1/refresh_token_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a'yandex/cloud/iam/v1/refresh_token.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"g\n" +
	"\x1aRevokeRefreshTokenMetadata\x12\x1d\n" +
	"\n" +
	"subject_id\x18\x01 \x01(\tR\tsubjectId\x12*\n" +
	"\x11refresh_token_ids\x18\x02 \x03(\tR\x0frefreshTokenIds\"\xc7\x01\n" +
	"\x18ListRefreshTokensRequest\x12'\n" +
	"\n" +
	"subject_id\x18\x01 \x01(\tB\b\x8a\xc81\x04<=50R\tsubjectId\x12'\n" +
	"\tpage_size\x18\x04 \x01(\x03B\n" +
	"\xfa\xc71\x060-1000R\bpageSize\x12)\n" +
	"\n" +
	"page_token\x18\x05 \x01(\tB\n" +
	"\x8a\xc81\x06<=2000R\tpageToken\x12\"\n" +
	"\x06filter\x18\x06 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\x06filterJ\x04\b\x02\x10\x03J\x04\b\x03\x10\x04\"\x8d\x01\n" +
	"\x19ListRefreshTokensResponse\x12H\n" +
	"\x0erefresh_tokens\x18\x01 \x03(\v2!.yandex.cloud.iam.v1.RefreshTokenR\rrefreshTokens\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xde\x01\n" +
	"\x19RevokeRefreshTokenRequest\x124\n" +
	"\x10refresh_token_id\x18\x01 \x01(\tB\b\x8a\xc81\x04<=50H\x00R\x0erefreshTokenId\x121\n" +
	"\rrefresh_token\x18\x02 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000H\x00R\frefreshToken\x12H\n" +
	"\rrevoke_filter\x18\x03 \x01(\v2!.yandex.cloud.iam.v1.RevokeFilterH\x00R\frevokeFilterB\x0e\n" +
	"\x06filter\x12\x04\xc0\xc11\x01\"\xa2\x01\n" +
	"\fRevokeFilter\x12%\n" +
	"\tclient_id\x18\x02 \x01(\tB\b\x8a\xc81\x04<=50R\bclientId\x12'\n" +
	"\n" +
	"subject_id\x18\x03 \x01(\tB\b\x8a\xc81\x04<=50R\tsubjectId\x12<\n" +
	"\x14client_instance_info\x18\x04 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\x12clientInstanceInfoJ\x04\b\x01\x10\x02\"H\n" +
	"\x1aRevokeRefreshTokenResponse\x12*\n" +
	"\x11refresh_token_ids\x18\x01 \x03(\tR\x0frefreshTokenIds2\xdf\x02\n" +
	"\x13RefreshTokenService\x12\x84\x01\n" +
	"\x04List\x12-.yandex.cloud.iam.v1.ListRefreshTokensRequest\x1a..yandex.cloud.iam.v1.ListRefreshTokensResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/iam/v1/refreshTokens\x12\xc0\x01\n" +
	"\x06Revoke\x12..yandex.cloud.iam.v1.RevokeRefreshTokenRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*8\n" +
	"\x1aRevokeRefreshTokenMetadata\x12\x1aRevokeRefreshTokenResponse\x82\xd3\xe4\x93\x02!:\x01*\"\x1c/iam/v1/refreshTokens:revokeBV\n" +
	"\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3"

var (
	file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescOnce sync.Once
	file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescData []byte
)

func file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescGZIP() []byte {
	file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDesc), len(file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDesc)))
	})
	return file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDescData
}

var file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes = make([]protoimpl.MessageInfo, 6)
var file_yandex_cloud_iam_v1_refresh_token_service_proto_goTypes = []any{
	(*RevokeRefreshTokenMetadata)(nil), // 0: yandex.cloud.iam.v1.RevokeRefreshTokenMetadata
	(*ListRefreshTokensRequest)(nil),   // 1: yandex.cloud.iam.v1.ListRefreshTokensRequest
	(*ListRefreshTokensResponse)(nil),  // 2: yandex.cloud.iam.v1.ListRefreshTokensResponse
	(*RevokeRefreshTokenRequest)(nil),  // 3: yandex.cloud.iam.v1.RevokeRefreshTokenRequest
	(*RevokeFilter)(nil),               // 4: yandex.cloud.iam.v1.RevokeFilter
	(*RevokeRefreshTokenResponse)(nil), // 5: yandex.cloud.iam.v1.RevokeRefreshTokenResponse
	(*RefreshToken)(nil),               // 6: yandex.cloud.iam.v1.RefreshToken
	(*operation.Operation)(nil),        // 7: yandex.cloud.operation.Operation
}
var file_yandex_cloud_iam_v1_refresh_token_service_proto_depIdxs = []int32{
	6, // 0: yandex.cloud.iam.v1.ListRefreshTokensResponse.refresh_tokens:type_name -> yandex.cloud.iam.v1.RefreshToken
	4, // 1: yandex.cloud.iam.v1.RevokeRefreshTokenRequest.revoke_filter:type_name -> yandex.cloud.iam.v1.RevokeFilter
	1, // 2: yandex.cloud.iam.v1.RefreshTokenService.List:input_type -> yandex.cloud.iam.v1.ListRefreshTokensRequest
	3, // 3: yandex.cloud.iam.v1.RefreshTokenService.Revoke:input_type -> yandex.cloud.iam.v1.RevokeRefreshTokenRequest
	2, // 4: yandex.cloud.iam.v1.RefreshTokenService.List:output_type -> yandex.cloud.iam.v1.ListRefreshTokensResponse
	7, // 5: yandex.cloud.iam.v1.RefreshTokenService.Revoke:output_type -> yandex.cloud.operation.Operation
	4, // [4:6] is the sub-list for method output_type
	2, // [2:4] is the sub-list for method input_type
	2, // [2:2] is the sub-list for extension type_name
	2, // [2:2] is the sub-list for extension extendee
	0, // [0:2] is the sub-list for field type_name
}

func init() { file_yandex_cloud_iam_v1_refresh_token_service_proto_init() }
func file_yandex_cloud_iam_v1_refresh_token_service_proto_init() {
	if File_yandex_cloud_iam_v1_refresh_token_service_proto != nil {
		return
	}
	file_yandex_cloud_iam_v1_refresh_token_proto_init()
	file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes[3].OneofWrappers = []any{
		(*RevokeRefreshTokenRequest_RefreshTokenId)(nil),
		(*RevokeRefreshTokenRequest_RefreshToken)(nil),
		(*RevokeRefreshTokenRequest_RevokeFilter)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDesc), len(file_yandex_cloud_iam_v1_refresh_token_service_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   6,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_yandex_cloud_iam_v1_refresh_token_service_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_iam_v1_refresh_token_service_proto_depIdxs,
		MessageInfos:      file_yandex_cloud_iam_v1_refresh_token_service_proto_msgTypes,
	}.Build()
	File_yandex_cloud_iam_v1_refresh_token_service_proto = out.File
	file_yandex_cloud_iam_v1_refresh_token_service_proto_goTypes = nil
	file_yandex_cloud_iam_v1_refresh_token_service_proto_depIdxs = nil
}
