// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/validation.proto

package cloud

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	descriptorpb "google.golang.org/protobuf/types/descriptorpb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type MapKeySpec struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Value         string                 `protobuf:"bytes,1,opt,name=value,proto3" json:"value,omitempty"`
	Pattern       string                 `protobuf:"bytes,2,opt,name=pattern,proto3" json:"pattern,omitempty"`
	Length        string                 `protobuf:"bytes,3,opt,name=length,proto3" json:"length,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *MapKeySpec) Reset() {
	*x = MapKeySpec{}
	mi := &file_yandex_cloud_validation_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *MapKeySpec) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*MapKeySpec) ProtoMessage() {}

func (x *MapKeySpec) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_validation_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use MapKeySpec.ProtoReflect.Descriptor instead.
func (*MapKeySpec) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_validation_proto_rawDescGZIP(), []int{0}
}

func (x *MapKeySpec) GetValue() string {
	if x != nil {
		return x.Value
	}
	return ""
}

func (x *MapKeySpec) GetPattern() string {
	if x != nil {
		return x.Pattern
	}
	return ""
}

func (x *MapKeySpec) GetLength() string {
	if x != nil {
		return x.Length
	}
	return ""
}

var file_yandex_cloud_validation_proto_extTypes = []protoimpl.ExtensionInfo{
	{
		ExtendedType:  (*descriptorpb.OneofOptions)(nil),
		ExtensionType: (*bool)(nil),
		Field:         101400,
		Name:          "yandex.cloud.exactly_one",
		Tag:           "varint,101400,opt,name=exactly_one",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*bool)(nil),
		Field:         101501,
		Name:          "yandex.cloud.required",
		Tag:           "varint,101501,opt,name=required",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*string)(nil),
		Field:         101502,
		Name:          "yandex.cloud.pattern",
		Tag:           "bytes,101502,opt,name=pattern",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*string)(nil),
		Field:         101503,
		Name:          "yandex.cloud.value",
		Tag:           "bytes,101503,opt,name=value",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*string)(nil),
		Field:         101504,
		Name:          "yandex.cloud.size",
		Tag:           "bytes,101504,opt,name=size",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*string)(nil),
		Field:         101505,
		Name:          "yandex.cloud.length",
		Tag:           "bytes,101505,opt,name=length",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*bool)(nil),
		Field:         101506,
		Name:          "yandex.cloud.unique",
		Tag:           "varint,101506,opt,name=unique",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*MapKeySpec)(nil),
		Field:         101510,
		Name:          "yandex.cloud.map_key",
		Tag:           "bytes,101510,opt,name=map_key",
		Filename:      "yandex/cloud/validation.proto",
	},
	{
		ExtendedType:  (*descriptorpb.FieldOptions)(nil),
		ExtensionType: (*string)(nil),
		Field:         101511,
		Name:          "yandex.cloud.bytes",
		Tag:           "bytes,101511,opt,name=bytes",
		Filename:      "yandex/cloud/validation.proto",
	},
}

// Extension fields to descriptorpb.OneofOptions.
var (
	// optional bool exactly_one = 101400;
	E_ExactlyOne = &file_yandex_cloud_validation_proto_extTypes[0]
)

// Extension fields to descriptorpb.FieldOptions.
var (
	// optional bool required = 101501;
	E_Required = &file_yandex_cloud_validation_proto_extTypes[1]
	// optional string pattern = 101502;
	E_Pattern = &file_yandex_cloud_validation_proto_extTypes[2]
	// optional string value = 101503;
	E_Value = &file_yandex_cloud_validation_proto_extTypes[3]
	// optional string size = 101504;
	E_Size = &file_yandex_cloud_validation_proto_extTypes[4]
	// optional string length = 101505;
	E_Length = &file_yandex_cloud_validation_proto_extTypes[5]
	// optional bool unique = 101506;
	E_Unique = &file_yandex_cloud_validation_proto_extTypes[6]
	// optional yandex.cloud.MapKeySpec map_key = 101510;
	E_MapKey = &file_yandex_cloud_validation_proto_extTypes[7]
	// optional string bytes = 101511;
	E_Bytes = &file_yandex_cloud_validation_proto_extTypes[8]
)

var File_yandex_cloud_validation_proto protoreflect.FileDescriptor

const file_yandex_cloud_validation_proto_rawDesc = "" +
	"\n" +
	"\x1dyandex/cloud/validation.proto\x12\fyandex.cloud\x1a google/protobuf/descriptor.proto\"T\n" +
	"\n" +
	"MapKeySpec\x12\x14\n" +
	"\x05value\x18\x01 \x01(\tR\x05value\x12\x18\n" +
	"\apattern\x18\x02 \x01(\tR\apattern\x12\x16\n" +
	"\x06length\x18\x03 \x01(\tR\x06length:@\n" +
	"\vexactly_one\x12\x1d.google.protobuf.OneofOptions\x18\x98\x98\x06 \x01(\bR\n" +
	"exactlyOne:;\n" +
	"\brequired\x12\x1d.google.protobuf.FieldOptions\x18\xfd\x98\x06 \x01(\bR\brequired:9\n" +
	"\apattern\x12\x1d.google.protobuf.FieldOptions\x18\xfe\x98\x06 \x01(\tR\apattern:5\n" +
	"\x05value\x12\x1d.google.protobuf.FieldOptions\x18\xff\x98\x06 \x01(\tR\x05value:3\n" +
	"\x04size\x12\x1d.google.protobuf.FieldOptions\x18\x80\x99\x06 \x01(\tR\x04size:7\n" +
	"\x06length\x12\x1d.google.protobuf.FieldOptions\x18\x81\x99\x06 \x01(\tR\x06length:7\n" +
	"\x06unique\x12\x1d.google.protobuf.FieldOptions\x18\x82\x99\x06 \x01(\bR\x06unique:R\n" +
	"\amap_key\x12\x1d.google.protobuf.FieldOptions\x18\x86\x99\x06 \x01(\v2\x18.yandex.cloud.MapKeySpecR\x06mapKey:5\n" +
	"\x05bytes\x12\x1d.google.protobuf.FieldOptions\x18\x87\x99\x06 \x01(\tR\x05bytesBJ\n" +
	"\x10yandex.cloud.apiZ6github.com/yandex-cloud/go-genproto/yandex/cloud;cloudb\x06proto3"

var (
	file_yandex_cloud_validation_proto_rawDescOnce sync.Once
	file_yandex_cloud_validation_proto_rawDescData []byte
)

func file_yandex_cloud_validation_proto_rawDescGZIP() []byte {
	file_yandex_cloud_validation_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_validation_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_validation_proto_rawDesc), len(file_yandex_cloud_validation_proto_rawDesc)))
	})
	return file_yandex_cloud_validation_proto_rawDescData
}

var file_yandex_cloud_validation_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_yandex_cloud_validation_proto_goTypes = []any{
	(*MapKeySpec)(nil),                // 0: yandex.cloud.MapKeySpec
	(*descriptorpb.OneofOptions)(nil), // 1: google.protobuf.OneofOptions
	(*descriptorpb.FieldOptions)(nil), // 2: google.protobuf.FieldOptions
}
var file_yandex_cloud_validation_proto_depIdxs = []int32{
	1,  // 0: yandex.cloud.exactly_one:extendee -> google.protobuf.OneofOptions
	2,  // 1: yandex.cloud.required:extendee -> google.protobuf.FieldOptions
	2,  // 2: yandex.cloud.pattern:extendee -> google.protobuf.FieldOptions
	2,  // 3: yandex.cloud.value:extendee -> google.protobuf.FieldOptions
	2,  // 4: yandex.cloud.size:extendee -> google.protobuf.FieldOptions
	2,  // 5: yandex.cloud.length:extendee -> google.protobuf.FieldOptions
	2,  // 6: yandex.cloud.unique:extendee -> google.protobuf.FieldOptions
	2,  // 7: yandex.cloud.map_key:extendee -> google.protobuf.FieldOptions
	2,  // 8: yandex.cloud.bytes:extendee -> google.protobuf.FieldOptions
	0,  // 9: yandex.cloud.map_key:type_name -> yandex.cloud.MapKeySpec
	10, // [10:10] is the sub-list for method output_type
	10, // [10:10] is the sub-list for method input_type
	9,  // [9:10] is the sub-list for extension type_name
	0,  // [0:9] is the sub-list for extension extendee
	0,  // [0:0] is the sub-list for field type_name
}

func init() { file_yandex_cloud_validation_proto_init() }
func file_yandex_cloud_validation_proto_init() {
	if File_yandex_cloud_validation_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_validation_proto_rawDesc), len(file_yandex_cloud_validation_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 9,
			NumServices:   0,
		},
		GoTypes:           file_yandex_cloud_validation_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_validation_proto_depIdxs,
		MessageInfos:      file_yandex_cloud_validation_proto_msgTypes,
		ExtensionInfos:    file_yandex_cloud_validation_proto_extTypes,
	}.Build()
	File_yandex_cloud_validation_proto = out.File
	file_yandex_cloud_validation_proto_goTypes = nil
	file_yandex_cloud_validation_proto_depIdxs = nil
}
