// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

func (m *GetRoleRequest) SetRoleId(v string) {
	m.RoleId = v
}

func (m *ListRolesRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListRolesRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListRolesRequest) SetFilter(v string) {
	m.Filter = v
}

func (m *ListRolesResponse) SetRoles(v []*Role) {
	m.Roles = v
}

func (m *ListRolesResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}
