package ucloud

import (
	"github.com/ucloud/ucloud-sdk-go/ucloud/request"
)

var (
	String            = request.String
	StringValue       = request.StringValue
	Int               = request.Int
	IntValue          = request.IntValue
	Bool              = request.Bool
	BoolValue         = request.BoolValue
	Float64           = request.Float64
	Float64Value      = request.Float64Value
	TimeDuration      = request.TimeDuration
	TimeDurationValue = request.TimeDurationValue
)
