// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

import (
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	fieldmaskpb "google.golang.org/protobuf/types/known/fieldmaskpb"
)

func (m *GetKeyRequest) SetKeyId(v string) {
	m.KeyId = v
}

func (m *GetKeyRequest) SetFormat(v KeyFormat) {
	m.Format = v
}

func (m *ListKeysRequest) SetFormat(v KeyFormat) {
	m.Format = v
}

func (m *ListKeysRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *ListKeysRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListKeysRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListKeysResponse) SetKeys(v []*Key) {
	m.Keys = v
}

func (m *ListKeysResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}

func (m *CreateKeyRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *CreateKeyRequest) SetDescription(v string) {
	m.Description = v
}

func (m *CreateKeyRequest) SetFormat(v KeyFormat) {
	m.Format = v
}

func (m *CreateKeyRequest) SetKeyAlgorithm(v Key_Algorithm) {
	m.KeyAlgorithm = v
}

func (m *CreateKeyResponse) SetKey(v *Key) {
	m.Key = v
}

func (m *CreateKeyResponse) SetPrivateKey(v string) {
	m.PrivateKey = v
}

func (m *UpdateKeyRequest) SetKeyId(v string) {
	m.KeyId = v
}

func (m *UpdateKeyRequest) SetUpdateMask(v *fieldmaskpb.FieldMask) {
	m.UpdateMask = v
}

func (m *UpdateKeyRequest) SetDescription(v string) {
	m.Description = v
}

func (m *UpdateKeyMetadata) SetKeyId(v string) {
	m.KeyId = v
}

func (m *DeleteKeyRequest) SetKeyId(v string) {
	m.KeyId = v
}

func (m *DeleteKeyMetadata) SetKeyId(v string) {
	m.KeyId = v
}

func (m *ListKeyOperationsRequest) SetKeyId(v string) {
	m.KeyId = v
}

func (m *ListKeyOperationsRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListKeyOperationsRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListKeyOperationsResponse) SetOperations(v []*operation.Operation) {
	m.Operations = v
}

func (m *ListKeyOperationsResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}
