// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

import (
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	fieldmaskpb "google.golang.org/protobuf/types/known/fieldmaskpb"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
)

func (m *GetApiKeyRequest) SetApiKeyId(v string) {
	m.ApiKeyId = v
}

func (m *ListApiKeysRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *ListApiKeysRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListApiKeysRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListApiKeysResponse) SetApiKeys(v []*ApiKey) {
	m.ApiKeys = v
}

func (m *ListApiKeysResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}

func (m *CreateApiKeyRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *CreateApiKeyRequest) SetDescription(v string) {
	m.Description = v
}

func (m *CreateApiKeyRequest) SetScope(v string) {
	m.Scope = v
}

func (m *CreateApiKeyRequest) SetScopes(v []string) {
	m.Scopes = v
}

func (m *CreateApiKeyRequest) SetExpiresAt(v *timestamppb.Timestamp) {
	m.ExpiresAt = v
}

func (m *CreateApiKeyResponse) SetApiKey(v *ApiKey) {
	m.ApiKey = v
}

func (m *CreateApiKeyResponse) SetSecret(v string) {
	m.Secret = v
}

func (m *UpdateApiKeyRequest) SetApiKeyId(v string) {
	m.ApiKeyId = v
}

func (m *UpdateApiKeyRequest) SetUpdateMask(v *fieldmaskpb.FieldMask) {
	m.UpdateMask = v
}

func (m *UpdateApiKeyRequest) SetDescription(v string) {
	m.Description = v
}

func (m *UpdateApiKeyRequest) SetScopes(v []string) {
	m.Scopes = v
}

func (m *UpdateApiKeyRequest) SetExpiresAt(v *timestamppb.Timestamp) {
	m.ExpiresAt = v
}

func (m *UpdateApiKeyMetadata) SetApiKeyId(v string) {
	m.ApiKeyId = v
}

func (m *DeleteApiKeyRequest) SetApiKeyId(v string) {
	m.ApiKeyId = v
}

func (m *DeleteApiKeyMetadata) SetApiKeyId(v string) {
	m.ApiKeyId = v
}

func (m *ListApiKeyOperationsRequest) SetApiKeyId(v string) {
	m.ApiKeyId = v
}

func (m *ListApiKeyOperationsRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListApiKeyOperationsRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListApiKeyOperationsResponse) SetOperations(v []*operation.Operation) {
	m.Operations = v
}

func (m *ListApiKeyOperationsResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}

func (m *ListApiKeyScopesRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListApiKeyScopesRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListApiKeyScopesResponse) SetScopes(v []string) {
	m.Scopes = v
}

func (m *ListApiKeyScopesResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}
