// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/iam/v1/service_control_service.proto

package iam

import (
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud"
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud/api"
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GetServiceRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the Service.
	ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
	// Resource container to get a service information in.
	//
	// It is supported only resource-manager.cloud resource container now.
	Resource      *Resource `protobuf:"bytes,2,opt,name=resource,proto3" json:"resource,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetServiceRequest) Reset() {
	*x = GetServiceRequest{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetServiceRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetServiceRequest) ProtoMessage() {}

func (x *GetServiceRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetServiceRequest.ProtoReflect.Descriptor instead.
func (*GetServiceRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{0}
}

func (x *GetServiceRequest) GetServiceId() string {
	if x != nil {
		return x.ServiceId
	}
	return ""
}

func (x *GetServiceRequest) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

type ListServicesRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Resource container to list a services.
	//
	// It is supported only resource-manager.cloud resource container now.
	Resource *Resource `protobuf:"bytes,1,opt,name=resource,proto3" json:"resource,omitempty"`
	// The maximum number of results per page to return. If the number of available
	// results is larger than [page_size],
	// the service returns a [ListServicesResponse.next_page_token]
	// that can be used to get the next page of results in subsequent list requests.
	// Default value: 100
	PageSize int64 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Page token. To get the next page of results, set [page_token]
	// to the [ListServicesResponse.next_page_token]
	// returned by a previous list request.
	PageToken     string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListServicesRequest) Reset() {
	*x = ListServicesRequest{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListServicesRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListServicesRequest) ProtoMessage() {}

func (x *ListServicesRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListServicesRequest.ProtoReflect.Descriptor instead.
func (*ListServicesRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{1}
}

func (x *ListServicesRequest) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

func (x *ListServicesRequest) GetPageSize() int64 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListServicesRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

type ListServicesResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// List of Services.
	Services []*Service `protobuf:"bytes,1,rep,name=services,proto3" json:"services,omitempty"`
	// This token allows you to get the next page of results for list requests. If the number of results
	// is larger than [ListServicesRequest.page_size], use
	// the [next_page_token] as the value
	// for the [ListServicesRequest.page_token] query parameter
	// in the next list request. Each subsequent list request will have its own
	// [next_page_token] to continue paging through the results.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListServicesResponse) Reset() {
	*x = ListServicesResponse{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListServicesResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListServicesResponse) ProtoMessage() {}

func (x *ListServicesResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListServicesResponse.ProtoReflect.Descriptor instead.
func (*ListServicesResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{2}
}

func (x *ListServicesResponse) GetServices() []*Service {
	if x != nil {
		return x.Services
	}
	return nil
}

func (x *ListServicesResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

type EnableServiceRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the Service.
	ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
	// Resource container to enable a service in.
	//
	// It is supported only resource-manager.cloud resource container now.
	Resource      *Resource `protobuf:"bytes,2,opt,name=resource,proto3" json:"resource,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EnableServiceRequest) Reset() {
	*x = EnableServiceRequest{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EnableServiceRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EnableServiceRequest) ProtoMessage() {}

func (x *EnableServiceRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EnableServiceRequest.ProtoReflect.Descriptor instead.
func (*EnableServiceRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{3}
}

func (x *EnableServiceRequest) GetServiceId() string {
	if x != nil {
		return x.ServiceId
	}
	return ""
}

func (x *EnableServiceRequest) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

type EnableServiceMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the Service.
	ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
	// Resource container.
	Resource      *Resource `protobuf:"bytes,2,opt,name=resource,proto3" json:"resource,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EnableServiceMetadata) Reset() {
	*x = EnableServiceMetadata{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EnableServiceMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EnableServiceMetadata) ProtoMessage() {}

func (x *EnableServiceMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EnableServiceMetadata.ProtoReflect.Descriptor instead.
func (*EnableServiceMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{4}
}

func (x *EnableServiceMetadata) GetServiceId() string {
	if x != nil {
		return x.ServiceId
	}
	return ""
}

func (x *EnableServiceMetadata) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

type DisableServiceRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the Service.
	ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
	// Resource container to disable a service in.
	//
	// It is supported only resource-manager.cloud resource container now.
	Resource      *Resource `protobuf:"bytes,2,opt,name=resource,proto3" json:"resource,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DisableServiceRequest) Reset() {
	*x = DisableServiceRequest{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DisableServiceRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DisableServiceRequest) ProtoMessage() {}

func (x *DisableServiceRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DisableServiceRequest.ProtoReflect.Descriptor instead.
func (*DisableServiceRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{5}
}

func (x *DisableServiceRequest) GetServiceId() string {
	if x != nil {
		return x.ServiceId
	}
	return ""
}

func (x *DisableServiceRequest) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

type DisableServiceMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the Service.
	ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
	// Resource container.
	Resource      *Resource `protobuf:"bytes,2,opt,name=resource,proto3" json:"resource,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DisableServiceMetadata) Reset() {
	*x = DisableServiceMetadata{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DisableServiceMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DisableServiceMetadata) ProtoMessage() {}

func (x *DisableServiceMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DisableServiceMetadata.ProtoReflect.Descriptor instead.
func (*DisableServiceMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{6}
}

func (x *DisableServiceMetadata) GetServiceId() string {
	if x != nil {
		return x.ServiceId
	}
	return ""
}

func (x *DisableServiceMetadata) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

type ResolveServiceAgentRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the Service.
	ServiceId string `protobuf:"bytes,1,opt,name=service_id,json=serviceId,proto3" json:"service_id,omitempty"`
	// ID of the Microservice.
	MicroserviceId string `protobuf:"bytes,2,opt,name=microservice_id,json=microserviceId,proto3" json:"microservice_id,omitempty"`
	// Resource container.
	Resource      *Resource `protobuf:"bytes,3,opt,name=resource,proto3" json:"resource,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ResolveServiceAgentRequest) Reset() {
	*x = ResolveServiceAgentRequest{}
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ResolveServiceAgentRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ResolveServiceAgentRequest) ProtoMessage() {}

func (x *ResolveServiceAgentRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ResolveServiceAgentRequest.ProtoReflect.Descriptor instead.
func (*ResolveServiceAgentRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP(), []int{7}
}

func (x *ResolveServiceAgentRequest) GetServiceId() string {
	if x != nil {
		return x.ServiceId
	}
	return ""
}

func (x *ResolveServiceAgentRequest) GetMicroserviceId() string {
	if x != nil {
		return x.MicroserviceId
	}
	return ""
}

func (x *ResolveServiceAgentRequest) GetResource() *Resource {
	if x != nil {
		return x.Resource
	}
	return nil
}

var File_yandex_cloud_iam_v1_service_control_service_proto protoreflect.FileDescriptor

const file_yandex_cloud_iam_v1_service_control_service_proto_rawDesc = "" +
	"\n" +
	"1yandex/cloud/iam/v1/service_control_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/iam/v1/resource.proto\x1a)yandex/cloud/iam/v1/service_control.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x81\x01\n" +
	"\x11GetServiceRequest\x12+\n" +
	"\n" +
	"service_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\tserviceId\x12?\n" +
	"\bresource\x18\x02 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc71\x01R\bresource\"\xaa\x01\n" +
	"\x13ListServicesRequest\x12?\n" +
	"\bresource\x18\x01 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc71\x01R\bresource\x12'\n" +
	"\tpage_size\x18\x02 \x01(\x03B\n" +
	"\xfa\xc71\x060-1000R\bpageSize\x12)\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\n" +
	"\x8a\xc81\x06<=2000R\tpageToken\"x\n" +
	"\x14ListServicesResponse\x128\n" +
	"\bservices\x18\x01 \x03(\v2\x1c.yandex.cloud.iam.v1.ServiceR\bservices\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x84\x01\n" +
	"\x14EnableServiceRequest\x12+\n" +
	"\n" +
	"service_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\tserviceId\x12?\n" +
	"\bresource\x18\x02 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc71\x01R\bresource\"q\n" +
	"\x15EnableServiceMetadata\x12\x1d\n" +
	"\n" +
	"service_id\x18\x01 \x01(\tR\tserviceId\x129\n" +
	"\bresource\x18\x02 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceR\bresource\"\x85\x01\n" +
	"\x15DisableServiceRequest\x12+\n" +
	"\n" +
	"service_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\tserviceId\x12?\n" +
	"\bresource\x18\x02 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc71\x01R\bresource\"r\n" +
	"\x16DisableServiceMetadata\x12\x1d\n" +
	"\n" +
	"service_id\x18\x01 \x01(\tR\tserviceId\x129\n" +
	"\bresource\x18\x02 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceR\bresource\"\xbd\x01\n" +
	"\x1aResolveServiceAgentRequest\x12+\n" +
	"\n" +
	"service_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\tserviceId\x121\n" +
	"\x0fmicroservice_id\x18\x02 \x01(\tB\b\x8a\xc81\x04<=50R\x0emicroserviceId\x12?\n" +
	"\bresource\x18\x03 \x01(\v2\x1d.yandex.cloud.iam.v1.ResourceB\x04\xe8\xc71\x01R\bresource2\x8a\x06\n" +
	"\x15ServiceControlService\x12r\n" +
	"\x03Get\x12&.yandex.cloud.iam.v1.GetServiceRequest\x1a\x1c.yandex.cloud.iam.v1.Service\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/iam/v1/services/{service_id}\x12u\n" +
	"\x04List\x12(.yandex.cloud.iam.v1.ListServicesRequest\x1a).yandex.cloud.iam.v1.ListServicesResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/iam/v1/services\x12\xaa\x01\n" +
	"\x06Enable\x12).yandex.cloud.iam.v1.EnableServiceRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2* \n" +
	"\x15EnableServiceMetadata\x12\aService\x82\xd3\xe4\x93\x02(:\x01*\"#/iam/v1/service/{service_id}:enable\x12\xae\x01\n" +
	"\aDisable\x12*.yandex.cloud.iam.v1.DisableServiceRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*!\n" +
	"\x16DisableServiceMetadata\x12\aService\x82\xd3\xe4\x93\x02):\x01*\"$/iam/v1/service/{service_id}:disable\x12\xa7\x01\n" +
	"\fResolveAgent\x12/.yandex.cloud.iam.v1.ResolveServiceAgentRequest\x1a!.yandex.cloud.iam.v1.ServiceAgent\"C\x82\xd3\xe4\x93\x02=\x12;/iam/v1/service/{service_id}/microservice/{microservice_id}BV\n" +
	"\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3"

var (
	file_yandex_cloud_iam_v1_service_control_service_proto_rawDescOnce sync.Once
	file_yandex_cloud_iam_v1_service_control_service_proto_rawDescData []byte
)

func file_yandex_cloud_iam_v1_service_control_service_proto_rawDescGZIP() []byte {
	file_yandex_cloud_iam_v1_service_control_service_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_iam_v1_service_control_service_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_service_control_service_proto_rawDesc), len(file_yandex_cloud_iam_v1_service_control_service_proto_rawDesc)))
	})
	return file_yandex_cloud_iam_v1_service_control_service_proto_rawDescData
}

var file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes = make([]protoimpl.MessageInfo, 8)
var file_yandex_cloud_iam_v1_service_control_service_proto_goTypes = []any{
	(*GetServiceRequest)(nil),          // 0: yandex.cloud.iam.v1.GetServiceRequest
	(*ListServicesRequest)(nil),        // 1: yandex.cloud.iam.v1.ListServicesRequest
	(*ListServicesResponse)(nil),       // 2: yandex.cloud.iam.v1.ListServicesResponse
	(*EnableServiceRequest)(nil),       // 3: yandex.cloud.iam.v1.EnableServiceRequest
	(*EnableServiceMetadata)(nil),      // 4: yandex.cloud.iam.v1.EnableServiceMetadata
	(*DisableServiceRequest)(nil),      // 5: yandex.cloud.iam.v1.DisableServiceRequest
	(*DisableServiceMetadata)(nil),     // 6: yandex.cloud.iam.v1.DisableServiceMetadata
	(*ResolveServiceAgentRequest)(nil), // 7: yandex.cloud.iam.v1.ResolveServiceAgentRequest
	(*Resource)(nil),                   // 8: yandex.cloud.iam.v1.Resource
	(*Service)(nil),                    // 9: yandex.cloud.iam.v1.Service
	(*operation.Operation)(nil),        // 10: yandex.cloud.operation.Operation
	(*ServiceAgent)(nil),               // 11: yandex.cloud.iam.v1.ServiceAgent
}
var file_yandex_cloud_iam_v1_service_control_service_proto_depIdxs = []int32{
	8,  // 0: yandex.cloud.iam.v1.GetServiceRequest.resource:type_name -> yandex.cloud.iam.v1.Resource
	8,  // 1: yandex.cloud.iam.v1.ListServicesRequest.resource:type_name -> yandex.cloud.iam.v1.Resource
	9,  // 2: yandex.cloud.iam.v1.ListServicesResponse.services:type_name -> yandex.cloud.iam.v1.Service
	8,  // 3: yandex.cloud.iam.v1.EnableServiceRequest.resource:type_name -> yandex.cloud.iam.v1.Resource
	8,  // 4: yandex.cloud.iam.v1.EnableServiceMetadata.resource:type_name -> yandex.cloud.iam.v1.Resource
	8,  // 5: yandex.cloud.iam.v1.DisableServiceRequest.resource:type_name -> yandex.cloud.iam.v1.Resource
	8,  // 6: yandex.cloud.iam.v1.DisableServiceMetadata.resource:type_name -> yandex.cloud.iam.v1.Resource
	8,  // 7: yandex.cloud.iam.v1.ResolveServiceAgentRequest.resource:type_name -> yandex.cloud.iam.v1.Resource
	0,  // 8: yandex.cloud.iam.v1.ServiceControlService.Get:input_type -> yandex.cloud.iam.v1.GetServiceRequest
	1,  // 9: yandex.cloud.iam.v1.ServiceControlService.List:input_type -> yandex.cloud.iam.v1.ListServicesRequest
	3,  // 10: yandex.cloud.iam.v1.ServiceControlService.Enable:input_type -> yandex.cloud.iam.v1.EnableServiceRequest
	5,  // 11: yandex.cloud.iam.v1.ServiceControlService.Disable:input_type -> yandex.cloud.iam.v1.DisableServiceRequest
	7,  // 12: yandex.cloud.iam.v1.ServiceControlService.ResolveAgent:input_type -> yandex.cloud.iam.v1.ResolveServiceAgentRequest
	9,  // 13: yandex.cloud.iam.v1.ServiceControlService.Get:output_type -> yandex.cloud.iam.v1.Service
	2,  // 14: yandex.cloud.iam.v1.ServiceControlService.List:output_type -> yandex.cloud.iam.v1.ListServicesResponse
	10, // 15: yandex.cloud.iam.v1.ServiceControlService.Enable:output_type -> yandex.cloud.operation.Operation
	10, // 16: yandex.cloud.iam.v1.ServiceControlService.Disable:output_type -> yandex.cloud.operation.Operation
	11, // 17: yandex.cloud.iam.v1.ServiceControlService.ResolveAgent:output_type -> yandex.cloud.iam.v1.ServiceAgent
	13, // [13:18] is the sub-list for method output_type
	8,  // [8:13] is the sub-list for method input_type
	8,  // [8:8] is the sub-list for extension type_name
	8,  // [8:8] is the sub-list for extension extendee
	0,  // [0:8] is the sub-list for field type_name
}

func init() { file_yandex_cloud_iam_v1_service_control_service_proto_init() }
func file_yandex_cloud_iam_v1_service_control_service_proto_init() {
	if File_yandex_cloud_iam_v1_service_control_service_proto != nil {
		return
	}
	file_yandex_cloud_iam_v1_resource_proto_init()
	file_yandex_cloud_iam_v1_service_control_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_service_control_service_proto_rawDesc), len(file_yandex_cloud_iam_v1_service_control_service_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   8,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_yandex_cloud_iam_v1_service_control_service_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_iam_v1_service_control_service_proto_depIdxs,
		MessageInfos:      file_yandex_cloud_iam_v1_service_control_service_proto_msgTypes,
	}.Build()
	File_yandex_cloud_iam_v1_service_control_service_proto = out.File
	file_yandex_cloud_iam_v1_service_control_service_proto_goTypes = nil
	file_yandex_cloud_iam_v1_service_control_service_proto_depIdxs = nil
}
