// Code generated by 'internal/releaser'; DO NOT EDIT.

package main

const defaultVersion = "v4.35.2+dev-release"

var version = ""

func getVersion() string {
	if version == "" {
		return defaultVersion
	}

	return version
}
