// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

import (
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	fieldmaskpb "google.golang.org/protobuf/types/known/fieldmaskpb"
)

func (m *GetServiceAccountRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *ListServiceAccountsRequest) SetFolderId(v string) {
	m.FolderId = v
}

func (m *ListServiceAccountsRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListServiceAccountsRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListServiceAccountsRequest) SetFilter(v string) {
	m.Filter = v
}

func (m *ListServiceAccountsResponse) SetServiceAccounts(v []*ServiceAccount) {
	m.ServiceAccounts = v
}

func (m *ListServiceAccountsResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}

func (m *CreateServiceAccountRequest) SetFolderId(v string) {
	m.FolderId = v
}

func (m *CreateServiceAccountRequest) SetName(v string) {
	m.Name = v
}

func (m *CreateServiceAccountRequest) SetDescription(v string) {
	m.Description = v
}

func (m *CreateServiceAccountRequest) SetLabels(v map[string]string) {
	m.Labels = v
}

func (m *CreateServiceAccountMetadata) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *UpdateServiceAccountRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *UpdateServiceAccountRequest) SetUpdateMask(v *fieldmaskpb.FieldMask) {
	m.UpdateMask = v
}

func (m *UpdateServiceAccountRequest) SetName(v string) {
	m.Name = v
}

func (m *UpdateServiceAccountRequest) SetDescription(v string) {
	m.Description = v
}

func (m *UpdateServiceAccountRequest) SetLabels(v map[string]string) {
	m.Labels = v
}

func (m *UpdateServiceAccountMetadata) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *DeleteServiceAccountRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *DeleteServiceAccountMetadata) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *ListServiceAccountOperationsRequest) SetServiceAccountId(v string) {
	m.ServiceAccountId = v
}

func (m *ListServiceAccountOperationsRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListServiceAccountOperationsRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListServiceAccountOperationsResponse) SetOperations(v []*operation.Operation) {
	m.Operations = v
}

func (m *ListServiceAccountOperationsResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}
