// Code generated by protoc-gen-goext. DO NOT EDIT.

package operation

import (
	status "google.golang.org/genproto/googleapis/rpc/status"
	anypb "google.golang.org/protobuf/types/known/anypb"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
)

type Operation_Result = isOperation_Result

func (m *Operation) SetResult(v Operation_Result) {
	m.Result = v
}

func (m *Operation) SetId(v string) {
	m.Id = v
}

func (m *Operation) SetDescription(v string) {
	m.Description = v
}

func (m *Operation) SetCreatedAt(v *timestamppb.Timestamp) {
	m.CreatedAt = v
}

func (m *Operation) SetCreatedBy(v string) {
	m.CreatedBy = v
}

func (m *Operation) SetModifiedAt(v *timestamppb.Timestamp) {
	m.ModifiedAt = v
}

func (m *Operation) SetDone(v bool) {
	m.Done = v
}

func (m *Operation) SetMetadata(v *anypb.Any) {
	m.Metadata = v
}

func (m *Operation) SetError(v *status.Status) {
	m.Result = &Operation_Error{
		Error: v,
	}
}

func (m *Operation) SetResponse(v *anypb.Any) {
	m.Result = &Operation_Response{
		Response: v,
	}
}
