// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

import (
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
)

type Key_Subject = isKey_Subject

func (m *Key) SetSubject(v Key_Subject) {
	m.Subject = v
}

func (m *Key) SetId(v string) {
	m.Id = v
}

func (m *Key) SetUserAccountId(v string) {
	m.Subject = &Key_UserAccountId{
		UserAccountId: v,
	}
}

func (m *Key) SetServiceAccountId(v string) {
	m.Subject = &Key_ServiceAccountId{
		ServiceAccountId: v,
	}
}

func (m *Key) SetCreatedAt(v *timestamppb.Timestamp) {
	m.CreatedAt = v
}

func (m *Key) SetDescription(v string) {
	m.Description = v
}

func (m *Key) SetKeyAlgorithm(v Key_Algorithm) {
	m.KeyAlgorithm = v
}

func (m *Key) SetPublicKey(v string) {
	m.PublicKey = v
}

func (m *Key) SetLastUsedAt(v *timestamppb.Timestamp) {
	m.LastUsedAt = v
}
