// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/iam/v1/service_account.proto

package iam

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

// A ServiceAccount resource. For more information, see [Service accounts](/docs/iam/concepts/users/service-accounts).
type ServiceAccount struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the service account.
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// ID of the folder that the service account belongs to.
	FolderId string `protobuf:"bytes,2,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// Creation timestamp.
	CreatedAt *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	// Name of the service account.
	// The name is unique within the cloud. 3-63 characters long.
	Name string `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// Description of the service account. 0-256 characters long.
	Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
	// Resource labels as “ key:value “ pairs. Maximum of 64 per resource.
	Labels map[string]string `protobuf:"bytes,6,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// Timestamp for the last authentication of this service account.
	LastAuthenticatedAt *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=last_authenticated_at,json=lastAuthenticatedAt,proto3" json:"last_authenticated_at,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *ServiceAccount) Reset() {
	*x = ServiceAccount{}
	mi := &file_yandex_cloud_iam_v1_service_account_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ServiceAccount) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ServiceAccount) ProtoMessage() {}

func (x *ServiceAccount) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_iam_v1_service_account_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ServiceAccount.ProtoReflect.Descriptor instead.
func (*ServiceAccount) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_iam_v1_service_account_proto_rawDescGZIP(), []int{0}
}

func (x *ServiceAccount) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *ServiceAccount) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *ServiceAccount) GetCreatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.CreatedAt
	}
	return nil
}

func (x *ServiceAccount) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *ServiceAccount) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *ServiceAccount) GetLabels() map[string]string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *ServiceAccount) GetLastAuthenticatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.LastAuthenticatedAt
	}
	return nil
}

var File_yandex_cloud_iam_v1_service_account_proto protoreflect.FileDescriptor

const file_yandex_cloud_iam_v1_service_account_proto_rawDesc = "" +
	"\n" +
	")yandex/cloud/iam/v1/service_account.proto\x12\x13yandex.cloud.iam.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x82\x03\n" +
	"\x0eServiceAccount\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x1b\n" +
	"\tfolder_id\x18\x02 \x01(\tR\bfolderId\x129\n" +
	"\n" +
	"created_at\x18\x03 \x01(\v2\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x12\n" +
	"\x04name\x18\x04 \x01(\tR\x04name\x12 \n" +
	"\vdescription\x18\x05 \x01(\tR\vdescription\x12G\n" +
	"\x06labels\x18\x06 \x03(\v2/.yandex.cloud.iam.v1.ServiceAccount.LabelsEntryR\x06labels\x12N\n" +
	"\x15last_authenticated_at\x18\a \x01(\v2\x1a.google.protobuf.TimestampR\x13lastAuthenticatedAt\x1a9\n" +
	"\vLabelsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01BV\n" +
	"\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3"

var (
	file_yandex_cloud_iam_v1_service_account_proto_rawDescOnce sync.Once
	file_yandex_cloud_iam_v1_service_account_proto_rawDescData []byte
)

func file_yandex_cloud_iam_v1_service_account_proto_rawDescGZIP() []byte {
	file_yandex_cloud_iam_v1_service_account_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_iam_v1_service_account_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_service_account_proto_rawDesc), len(file_yandex_cloud_iam_v1_service_account_proto_rawDesc)))
	})
	return file_yandex_cloud_iam_v1_service_account_proto_rawDescData
}

var file_yandex_cloud_iam_v1_service_account_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_yandex_cloud_iam_v1_service_account_proto_goTypes = []any{
	(*ServiceAccount)(nil),        // 0: yandex.cloud.iam.v1.ServiceAccount
	nil,                           // 1: yandex.cloud.iam.v1.ServiceAccount.LabelsEntry
	(*timestamppb.Timestamp)(nil), // 2: google.protobuf.Timestamp
}
var file_yandex_cloud_iam_v1_service_account_proto_depIdxs = []int32{
	2, // 0: yandex.cloud.iam.v1.ServiceAccount.created_at:type_name -> google.protobuf.Timestamp
	1, // 1: yandex.cloud.iam.v1.ServiceAccount.labels:type_name -> yandex.cloud.iam.v1.ServiceAccount.LabelsEntry
	2, // 2: yandex.cloud.iam.v1.ServiceAccount.last_authenticated_at:type_name -> google.protobuf.Timestamp
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_yandex_cloud_iam_v1_service_account_proto_init() }
func file_yandex_cloud_iam_v1_service_account_proto_init() {
	if File_yandex_cloud_iam_v1_service_account_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_iam_v1_service_account_proto_rawDesc), len(file_yandex_cloud_iam_v1_service_account_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_yandex_cloud_iam_v1_service_account_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_iam_v1_service_account_proto_depIdxs,
		MessageInfos:      file_yandex_cloud_iam_v1_service_account_proto_msgTypes,
	}.Build()
	File_yandex_cloud_iam_v1_service_account_proto = out.File
	file_yandex_cloud_iam_v1_service_account_proto_goTypes = nil
	file_yandex_cloud_iam_v1_service_account_proto_depIdxs = nil
}
