// Copyright 2022-2025 The sacloud/iaas-api-go Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package types

type ESimpleNotificationDestinationTypes string

// String ESimpleNotificationDestinationTypesの文字列表現
func (p ESimpleNotificationDestinationTypes) String() string {
	return string(p)
}

// SimpleNotificationDestinationTypes シンプル通知 通知先タイプ
var SimpleNotificationDestinationTypes = struct {
	// EMail email
	EMail ESimpleNotificationDestinationTypes
	// Webhook webhook
	Webhook ESimpleNotificationDestinationTypes
}{
	EMail:   ESimpleNotificationDestinationTypes("email"),
	Webhook: ESimpleNotificationDestinationTypes("webhook"),
}

// SimpleNotificationDestinationTypeStrings 通知先タイプの文字列リスト
var SimpleNotificationDestinationTypeStrings = []string{
	SimpleNotificationDestinationTypes.EMail.String(),
	SimpleNotificationDestinationTypes.Webhook.String(),
}
