// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.11
// 	protoc        v3.21.12
// source: yandex/cloud/dns/v1/dns_endpoint_service.proto

package dns

import (
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud"
	access "github.com/yandex-cloud/go-genproto/yandex/cloud/access"
	_ "github.com/yandex-cloud/go-genproto/yandex/cloud/api"
	operation "github.com/yandex-cloud/go-genproto/yandex/cloud/operation"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	fieldmaskpb "google.golang.org/protobuf/types/known/fieldmaskpb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type GetDnsInboundEndpointRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint to return.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *GetDnsInboundEndpointRequest) Reset() {
	*x = GetDnsInboundEndpointRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetDnsInboundEndpointRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetDnsInboundEndpointRequest) ProtoMessage() {}

func (x *GetDnsInboundEndpointRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetDnsInboundEndpointRequest.ProtoReflect.Descriptor instead.
func (*GetDnsInboundEndpointRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{0}
}

func (x *GetDnsInboundEndpointRequest) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

type CreateDnsInboundEndpointRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the folder to create a DNS inbound endpoint in.
	FolderId string `protobuf:"bytes,2,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// Name of the DNS inbound endpoint.
	Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// Description of the DNS inbound endpoint.
	Description string `protobuf:"bytes,4,opt,name=description,proto3" json:"description,omitempty"`
	// DNS inbound endpoint labels as `key:value` pairs.
	Labels map[string]string `protobuf:"bytes,5,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// ID of the network to create a DNS inbound endpoint in.
	NetworkId string `protobuf:"bytes,6,opt,name=network_id,json=networkId,proto3" json:"network_id,omitempty"`
	// Prevents accidental endpoint removal.
	DeletionProtection bool `protobuf:"varint,7,opt,name=deletion_protection,json=deletionProtection,proto3" json:"deletion_protection,omitempty"`
	// ID of the address resource.
	AddressId     string `protobuf:"bytes,8,opt,name=address_id,json=addressId,proto3" json:"address_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateDnsInboundEndpointRequest) Reset() {
	*x = CreateDnsInboundEndpointRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDnsInboundEndpointRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDnsInboundEndpointRequest) ProtoMessage() {}

func (x *CreateDnsInboundEndpointRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDnsInboundEndpointRequest.ProtoReflect.Descriptor instead.
func (*CreateDnsInboundEndpointRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{1}
}

func (x *CreateDnsInboundEndpointRequest) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *CreateDnsInboundEndpointRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *CreateDnsInboundEndpointRequest) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *CreateDnsInboundEndpointRequest) GetLabels() map[string]string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *CreateDnsInboundEndpointRequest) GetNetworkId() string {
	if x != nil {
		return x.NetworkId
	}
	return ""
}

func (x *CreateDnsInboundEndpointRequest) GetDeletionProtection() bool {
	if x != nil {
		return x.DeletionProtection
	}
	return false
}

func (x *CreateDnsInboundEndpointRequest) GetAddressId() string {
	if x != nil {
		return x.AddressId
	}
	return ""
}

type CreateDnsInboundEndpointMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint that is being created.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *CreateDnsInboundEndpointMetadata) Reset() {
	*x = CreateDnsInboundEndpointMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateDnsInboundEndpointMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateDnsInboundEndpointMetadata) ProtoMessage() {}

func (x *CreateDnsInboundEndpointMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateDnsInboundEndpointMetadata.ProtoReflect.Descriptor instead.
func (*CreateDnsInboundEndpointMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{2}
}

func (x *CreateDnsInboundEndpointMetadata) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

type UpdateDnsInboundEndpointRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint to update.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	// Field mask that specifies which fields of the DNS inbound endpoint are going to be updated.
	UpdateMask *fieldmaskpb.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// ID of the folder that the DNS inbound endpoint belongs to.
	FolderId string `protobuf:"bytes,3,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// Name of the DNS inbound endpoint.
	Name string `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// Description of the DNS inbound endpoint.
	Description string `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
	// DNS inbound endpoint labels as `key:value` pairs.
	Labels map[string]string `protobuf:"bytes,6,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key" protobuf_val:"bytes,2,opt,name=value"`
	// Prevents accidental endpoint removal.
	DeletionProtection bool `protobuf:"varint,7,opt,name=deletion_protection,json=deletionProtection,proto3" json:"deletion_protection,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *UpdateDnsInboundEndpointRequest) Reset() {
	*x = UpdateDnsInboundEndpointRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateDnsInboundEndpointRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateDnsInboundEndpointRequest) ProtoMessage() {}

func (x *UpdateDnsInboundEndpointRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateDnsInboundEndpointRequest.ProtoReflect.Descriptor instead.
func (*UpdateDnsInboundEndpointRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{3}
}

func (x *UpdateDnsInboundEndpointRequest) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

func (x *UpdateDnsInboundEndpointRequest) GetUpdateMask() *fieldmaskpb.FieldMask {
	if x != nil {
		return x.UpdateMask
	}
	return nil
}

func (x *UpdateDnsInboundEndpointRequest) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *UpdateDnsInboundEndpointRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *UpdateDnsInboundEndpointRequest) GetDescription() string {
	if x != nil {
		return x.Description
	}
	return ""
}

func (x *UpdateDnsInboundEndpointRequest) GetLabels() map[string]string {
	if x != nil {
		return x.Labels
	}
	return nil
}

func (x *UpdateDnsInboundEndpointRequest) GetDeletionProtection() bool {
	if x != nil {
		return x.DeletionProtection
	}
	return false
}

type UpdateDnsInboundEndpointMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint that is being updated.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *UpdateDnsInboundEndpointMetadata) Reset() {
	*x = UpdateDnsInboundEndpointMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateDnsInboundEndpointMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateDnsInboundEndpointMetadata) ProtoMessage() {}

func (x *UpdateDnsInboundEndpointMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateDnsInboundEndpointMetadata.ProtoReflect.Descriptor instead.
func (*UpdateDnsInboundEndpointMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{4}
}

func (x *UpdateDnsInboundEndpointMetadata) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

type DeleteDnsInboundEndpointRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint to delete.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *DeleteDnsInboundEndpointRequest) Reset() {
	*x = DeleteDnsInboundEndpointRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteDnsInboundEndpointRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteDnsInboundEndpointRequest) ProtoMessage() {}

func (x *DeleteDnsInboundEndpointRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteDnsInboundEndpointRequest.ProtoReflect.Descriptor instead.
func (*DeleteDnsInboundEndpointRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{5}
}

func (x *DeleteDnsInboundEndpointRequest) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

type DeleteDnsInboundEndpointMetadata struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint that is being deleted.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *DeleteDnsInboundEndpointMetadata) Reset() {
	*x = DeleteDnsInboundEndpointMetadata{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteDnsInboundEndpointMetadata) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteDnsInboundEndpointMetadata) ProtoMessage() {}

func (x *DeleteDnsInboundEndpointMetadata) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteDnsInboundEndpointMetadata.ProtoReflect.Descriptor instead.
func (*DeleteDnsInboundEndpointMetadata) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{6}
}

func (x *DeleteDnsInboundEndpointMetadata) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

type ListDnsInboundEndpointsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the folder to list DNS inbound endpoints in.
	FolderId string `protobuf:"bytes,1,opt,name=folder_id,json=folderId,proto3" json:"folder_id,omitempty"`
	// The maximum number of results per page to return.
	PageSize int64 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Page token. To get the next page of results, set `page_token` to the value returned by a previous list request.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// A filter expression that filters resources listed in the response.
	Filter        string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsInboundEndpointsRequest) Reset() {
	*x = ListDnsInboundEndpointsRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsInboundEndpointsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsInboundEndpointsRequest) ProtoMessage() {}

func (x *ListDnsInboundEndpointsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsInboundEndpointsRequest.ProtoReflect.Descriptor instead.
func (*ListDnsInboundEndpointsRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{7}
}

func (x *ListDnsInboundEndpointsRequest) GetFolderId() string {
	if x != nil {
		return x.FolderId
	}
	return ""
}

func (x *ListDnsInboundEndpointsRequest) GetPageSize() int64 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListDnsInboundEndpointsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListDnsInboundEndpointsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

type ListDnsInboundEndpointsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// List of DNS inbound endpoints.
	Endpoints []*DnsInboundEndpoint `protobuf:"bytes,1,rep,name=endpoints,proto3" json:"endpoints,omitempty"`
	// Token for getting the next page of the list.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsInboundEndpointsResponse) Reset() {
	*x = ListDnsInboundEndpointsResponse{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsInboundEndpointsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsInboundEndpointsResponse) ProtoMessage() {}

func (x *ListDnsInboundEndpointsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsInboundEndpointsResponse.ProtoReflect.Descriptor instead.
func (*ListDnsInboundEndpointsResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{8}
}

func (x *ListDnsInboundEndpointsResponse) GetEndpoints() []*DnsInboundEndpoint {
	if x != nil {
		return x.Endpoints
	}
	return nil
}

func (x *ListDnsInboundEndpointsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

type ListDnsInboundEndpointOperationsRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// ID of the DNS inbound endpoint to list operations for.
	DnsInboundEndpointId string `protobuf:"bytes,1,opt,name=dns_inbound_endpoint_id,json=dnsInboundEndpointId,proto3" json:"dns_inbound_endpoint_id,omitempty"`
	// The maximum number of results per page to return.
	PageSize int64 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Page token. To get the next page of results, set `page_token` to the value returned by a previous list request.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// A filter expression that filters operations listed in the response.
	Filter        string `protobuf:"bytes,4,opt,name=filter,proto3" json:"filter,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsInboundEndpointOperationsRequest) Reset() {
	*x = ListDnsInboundEndpointOperationsRequest{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsInboundEndpointOperationsRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsInboundEndpointOperationsRequest) ProtoMessage() {}

func (x *ListDnsInboundEndpointOperationsRequest) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsInboundEndpointOperationsRequest.ProtoReflect.Descriptor instead.
func (*ListDnsInboundEndpointOperationsRequest) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{9}
}

func (x *ListDnsInboundEndpointOperationsRequest) GetDnsInboundEndpointId() string {
	if x != nil {
		return x.DnsInboundEndpointId
	}
	return ""
}

func (x *ListDnsInboundEndpointOperationsRequest) GetPageSize() int64 {
	if x != nil {
		return x.PageSize
	}
	return 0
}

func (x *ListDnsInboundEndpointOperationsRequest) GetPageToken() string {
	if x != nil {
		return x.PageToken
	}
	return ""
}

func (x *ListDnsInboundEndpointOperationsRequest) GetFilter() string {
	if x != nil {
		return x.Filter
	}
	return ""
}

type ListDnsInboundEndpointOperationsResponse struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// List of operations for the specified DNS inbound endpoint.
	Operations []*operation.Operation `protobuf:"bytes,1,rep,name=operations,proto3" json:"operations,omitempty"`
	// Token for getting the next page of the list.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ListDnsInboundEndpointOperationsResponse) Reset() {
	*x = ListDnsInboundEndpointOperationsResponse{}
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ListDnsInboundEndpointOperationsResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ListDnsInboundEndpointOperationsResponse) ProtoMessage() {}

func (x *ListDnsInboundEndpointOperationsResponse) ProtoReflect() protoreflect.Message {
	mi := &file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ListDnsInboundEndpointOperationsResponse.ProtoReflect.Descriptor instead.
func (*ListDnsInboundEndpointOperationsResponse) Descriptor() ([]byte, []int) {
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP(), []int{10}
}

func (x *ListDnsInboundEndpointOperationsResponse) GetOperations() []*operation.Operation {
	if x != nil {
		return x.Operations
	}
	return nil
}

func (x *ListDnsInboundEndpointOperationsResponse) GetNextPageToken() string {
	if x != nil {
		return x.NextPageToken
	}
	return ""
}

var File_yandex_cloud_dns_v1_dns_endpoint_service_proto protoreflect.FileDescriptor

const file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDesc = "" +
	"\n" +
	".yandex/cloud/dns/v1/dns_endpoint_service.proto\x12\x13yandex.cloud.dns.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/dns/v1/dns_endpoint.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"c\n" +
	"\x1cGetDnsInboundEndpointRequest\x12C\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\x14dnsInboundEndpointId\"\x9f\x04\n" +
	"\x1fCreateDnsInboundEndpointRequest\x12)\n" +
	"\tfolder_id\x18\x02 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\bfolderId\x128\n" +
	"\x04name\x18\x03 \x01(\tB$\xf2\xc71 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?R\x04name\x12+\n" +
	"\vdescription\x18\x04 \x01(\tB\t\x8a\xc81\x05<=256R\vdescription\x12\x9d\x01\n" +
	"\x06labels\x18\x05 \x03(\v2@.yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest.LabelsEntryBC\xf2\xc71\x0f[-_./\\@0-9a-z]*\x82\xc81\x04<=64\x8a\xc81\x04<=63\xb2\xc81\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x041-63R\x06labels\x12+\n" +
	"\n" +
	"network_id\x18\x06 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\tnetworkId\x12/\n" +
	"\x13deletion_protection\x18\a \x01(\bR\x12deletionProtection\x12+\n" +
	"\n" +
	"address_id\x18\b \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\taddressId\x1a9\n" +
	"\vLabelsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01J\x04\b\x01\x10\x02\"Y\n" +
	" CreateDnsInboundEndpointMetadata\x125\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tR\x14dnsInboundEndpointId\"\xbd\x04\n" +
	"\x1fUpdateDnsInboundEndpointRequest\x12C\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\x14dnsInboundEndpointId\x12;\n" +
	"\vupdate_mask\x18\x02 \x01(\v2\x1a.google.protobuf.FieldMaskR\n" +
	"updateMask\x12%\n" +
	"\tfolder_id\x18\x03 \x01(\tB\b\x8a\xc81\x04<=50R\bfolderId\x128\n" +
	"\x04name\x18\x04 \x01(\tB$\xf2\xc71 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?R\x04name\x12+\n" +
	"\vdescription\x18\x05 \x01(\tB\t\x8a\xc81\x05<=256R\vdescription\x12\x9d\x01\n" +
	"\x06labels\x18\x06 \x03(\v2@.yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest.LabelsEntryBC\xf2\xc71\x0f[-_./\\@0-9a-z]*\x82\xc81\x04<=64\x8a\xc81\x04<=63\xb2\xc81\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x041-63R\x06labels\x12/\n" +
	"\x13deletion_protection\x18\a \x01(\bR\x12deletionProtection\x1a9\n" +
	"\vLabelsEntry\x12\x10\n" +
	"\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n" +
	"\x05value\x18\x02 \x01(\tR\x05value:\x028\x01\"Y\n" +
	" UpdateDnsInboundEndpointMetadata\x125\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tR\x14dnsInboundEndpointId\"f\n" +
	"\x1fDeleteDnsInboundEndpointRequest\x12C\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\x14dnsInboundEndpointId\"Y\n" +
	" DeleteDnsInboundEndpointMetadata\x125\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tR\x14dnsInboundEndpointId\"\xbf\x01\n" +
	"\x1eListDnsInboundEndpointsRequest\x12%\n" +
	"\tfolder_id\x18\x01 \x01(\tB\b\x8a\xc81\x04<=50R\bfolderId\x12'\n" +
	"\tpage_size\x18\x02 \x01(\x03B\n" +
	"\xfa\xc71\x060-1000R\bpageSize\x12)\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\tpageToken\x12\"\n" +
	"\x06filter\x18\x04 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\x06filter\"\x90\x01\n" +
	"\x1fListDnsInboundEndpointsResponse\x12E\n" +
	"\tendpoints\x18\x01 \x03(\v2'.yandex.cloud.dns.v1.DnsInboundEndpointR\tendpoints\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xe6\x01\n" +
	"'ListDnsInboundEndpointOperationsRequest\x12C\n" +
	"\x17dns_inbound_endpoint_id\x18\x01 \x01(\tB\f\xe8\xc71\x01\x8a\xc81\x04<=50R\x14dnsInboundEndpointId\x12'\n" +
	"\tpage_size\x18\x02 \x01(\x03B\n" +
	"\xfa\xc71\x06<=1000R\bpageSize\x12)\n" +
	"\n" +
	"page_token\x18\x03 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\tpageToken\x12\"\n" +
	"\x06filter\x18\x04 \x01(\tB\n" +
	"\x8a\xc81\x06<=1000R\x06filter\"\x95\x01\n" +
	"(ListDnsInboundEndpointOperationsResponse\x12A\n" +
	"\n" +
	"operations\x18\x01 \x03(\v2!.yandex.cloud.operation.OperationR\n" +
	"operations\x12&\n" +
	"\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xc2\x0e\n" +
	"\x19DnsInboundEndpointService\x12\x9d\x01\n" +
	"\x03Get\x121.yandex.cloud.dns.v1.GetDnsInboundEndpointRequest\x1a'.yandex.cloud.dns.v1.DnsInboundEndpoint\":\x82\xd3\xe4\x93\x024\x122/dns/v1/inboundEndpoints/{dns_inbound_endpoint_id}\x12\x93\x01\n" +
	"\x04List\x123.yandex.cloud.dns.v1.ListDnsInboundEndpointsRequest\x1a4.yandex.cloud.dns.v1.ListDnsInboundEndpointsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/dns/v1/inboundEndpoints\x12\xc0\x01\n" +
	"\x06Create\x124.yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*6\n" +
	" CreateDnsInboundEndpointMetadata\x12\x12DnsInboundEndpoint\x82\xd3\xe4\x93\x02\x1d:\x01*\"\x18/dns/v1/inboundEndpoints\x12\xda\x01\n" +
	"\x06Update\x124.yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*6\n" +
	" UpdateDnsInboundEndpointMetadata\x12\x12DnsInboundEndpoint\x82\xd3\xe4\x93\x027:\x01*22/dns/v1/inboundEndpoints/{dns_inbound_endpoint_id}\x12\xda\x01\n" +
	"\x06Delete\x124.yandex.cloud.dns.v1.DeleteDnsInboundEndpointRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*9\n" +
	" DeleteDnsInboundEndpointMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x024*2/dns/v1/inboundEndpoints/{dns_inbound_endpoint_id}\x12\xd4\x01\n" +
	"\x0eListOperations\x12<.yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsRequest\x1a=.yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/dns/v1/inboundEndpoints/{dns_inbound_endpoint_id}/operations\x12\xb8\x01\n" +
	"\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"A\x82\xd3\xe4\x93\x02;\x129/dns/v1/inboundEndpoints/{resource_id}:listAccessBindings\x12\xe8\x01\n" +
	"\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*9\n" +
	" access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=:\x01*\"8/dns/v1/inboundEndpoints/{resource_id}:setAccessBindings\x12\xf4\x01\n" +
	"\x14UpdateAccessBindings\x120.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*<\n" +
	"#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@:\x01*\";/dns/v1/inboundEndpoints/{resource_id}:updateAccessBindingsBV\n" +
	"\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3"

var (
	file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescOnce sync.Once
	file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescData []byte
)

func file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescGZIP() []byte {
	file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescOnce.Do(func() {
		file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDesc), len(file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDesc)))
	})
	return file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDescData
}

var file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes = make([]protoimpl.MessageInfo, 13)
var file_yandex_cloud_dns_v1_dns_endpoint_service_proto_goTypes = []any{
	(*GetDnsInboundEndpointRequest)(nil),             // 0: yandex.cloud.dns.v1.GetDnsInboundEndpointRequest
	(*CreateDnsInboundEndpointRequest)(nil),          // 1: yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest
	(*CreateDnsInboundEndpointMetadata)(nil),         // 2: yandex.cloud.dns.v1.CreateDnsInboundEndpointMetadata
	(*UpdateDnsInboundEndpointRequest)(nil),          // 3: yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest
	(*UpdateDnsInboundEndpointMetadata)(nil),         // 4: yandex.cloud.dns.v1.UpdateDnsInboundEndpointMetadata
	(*DeleteDnsInboundEndpointRequest)(nil),          // 5: yandex.cloud.dns.v1.DeleteDnsInboundEndpointRequest
	(*DeleteDnsInboundEndpointMetadata)(nil),         // 6: yandex.cloud.dns.v1.DeleteDnsInboundEndpointMetadata
	(*ListDnsInboundEndpointsRequest)(nil),           // 7: yandex.cloud.dns.v1.ListDnsInboundEndpointsRequest
	(*ListDnsInboundEndpointsResponse)(nil),          // 8: yandex.cloud.dns.v1.ListDnsInboundEndpointsResponse
	(*ListDnsInboundEndpointOperationsRequest)(nil),  // 9: yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsRequest
	(*ListDnsInboundEndpointOperationsResponse)(nil), // 10: yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsResponse
	nil,                                      // 11: yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest.LabelsEntry
	nil,                                      // 12: yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest.LabelsEntry
	(*fieldmaskpb.FieldMask)(nil),            // 13: google.protobuf.FieldMask
	(*DnsInboundEndpoint)(nil),               // 14: yandex.cloud.dns.v1.DnsInboundEndpoint
	(*operation.Operation)(nil),              // 15: yandex.cloud.operation.Operation
	(*access.ListAccessBindingsRequest)(nil), // 16: yandex.cloud.access.ListAccessBindingsRequest
	(*access.SetAccessBindingsRequest)(nil),  // 17: yandex.cloud.access.SetAccessBindingsRequest
	(*access.UpdateAccessBindingsRequest)(nil), // 18: yandex.cloud.access.UpdateAccessBindingsRequest
	(*access.ListAccessBindingsResponse)(nil),  // 19: yandex.cloud.access.ListAccessBindingsResponse
}
var file_yandex_cloud_dns_v1_dns_endpoint_service_proto_depIdxs = []int32{
	11, // 0: yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest.labels:type_name -> yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest.LabelsEntry
	13, // 1: yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest.update_mask:type_name -> google.protobuf.FieldMask
	12, // 2: yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest.labels:type_name -> yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest.LabelsEntry
	14, // 3: yandex.cloud.dns.v1.ListDnsInboundEndpointsResponse.endpoints:type_name -> yandex.cloud.dns.v1.DnsInboundEndpoint
	15, // 4: yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsResponse.operations:type_name -> yandex.cloud.operation.Operation
	0,  // 5: yandex.cloud.dns.v1.DnsInboundEndpointService.Get:input_type -> yandex.cloud.dns.v1.GetDnsInboundEndpointRequest
	7,  // 6: yandex.cloud.dns.v1.DnsInboundEndpointService.List:input_type -> yandex.cloud.dns.v1.ListDnsInboundEndpointsRequest
	1,  // 7: yandex.cloud.dns.v1.DnsInboundEndpointService.Create:input_type -> yandex.cloud.dns.v1.CreateDnsInboundEndpointRequest
	3,  // 8: yandex.cloud.dns.v1.DnsInboundEndpointService.Update:input_type -> yandex.cloud.dns.v1.UpdateDnsInboundEndpointRequest
	5,  // 9: yandex.cloud.dns.v1.DnsInboundEndpointService.Delete:input_type -> yandex.cloud.dns.v1.DeleteDnsInboundEndpointRequest
	9,  // 10: yandex.cloud.dns.v1.DnsInboundEndpointService.ListOperations:input_type -> yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsRequest
	16, // 11: yandex.cloud.dns.v1.DnsInboundEndpointService.ListAccessBindings:input_type -> yandex.cloud.access.ListAccessBindingsRequest
	17, // 12: yandex.cloud.dns.v1.DnsInboundEndpointService.SetAccessBindings:input_type -> yandex.cloud.access.SetAccessBindingsRequest
	18, // 13: yandex.cloud.dns.v1.DnsInboundEndpointService.UpdateAccessBindings:input_type -> yandex.cloud.access.UpdateAccessBindingsRequest
	14, // 14: yandex.cloud.dns.v1.DnsInboundEndpointService.Get:output_type -> yandex.cloud.dns.v1.DnsInboundEndpoint
	8,  // 15: yandex.cloud.dns.v1.DnsInboundEndpointService.List:output_type -> yandex.cloud.dns.v1.ListDnsInboundEndpointsResponse
	15, // 16: yandex.cloud.dns.v1.DnsInboundEndpointService.Create:output_type -> yandex.cloud.operation.Operation
	15, // 17: yandex.cloud.dns.v1.DnsInboundEndpointService.Update:output_type -> yandex.cloud.operation.Operation
	15, // 18: yandex.cloud.dns.v1.DnsInboundEndpointService.Delete:output_type -> yandex.cloud.operation.Operation
	10, // 19: yandex.cloud.dns.v1.DnsInboundEndpointService.ListOperations:output_type -> yandex.cloud.dns.v1.ListDnsInboundEndpointOperationsResponse
	19, // 20: yandex.cloud.dns.v1.DnsInboundEndpointService.ListAccessBindings:output_type -> yandex.cloud.access.ListAccessBindingsResponse
	15, // 21: yandex.cloud.dns.v1.DnsInboundEndpointService.SetAccessBindings:output_type -> yandex.cloud.operation.Operation
	15, // 22: yandex.cloud.dns.v1.DnsInboundEndpointService.UpdateAccessBindings:output_type -> yandex.cloud.operation.Operation
	14, // [14:23] is the sub-list for method output_type
	5,  // [5:14] is the sub-list for method input_type
	5,  // [5:5] is the sub-list for extension type_name
	5,  // [5:5] is the sub-list for extension extendee
	0,  // [0:5] is the sub-list for field type_name
}

func init() { file_yandex_cloud_dns_v1_dns_endpoint_service_proto_init() }
func file_yandex_cloud_dns_v1_dns_endpoint_service_proto_init() {
	if File_yandex_cloud_dns_v1_dns_endpoint_service_proto != nil {
		return
	}
	file_yandex_cloud_dns_v1_dns_endpoint_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDesc), len(file_yandex_cloud_dns_v1_dns_endpoint_service_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   13,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_yandex_cloud_dns_v1_dns_endpoint_service_proto_goTypes,
		DependencyIndexes: file_yandex_cloud_dns_v1_dns_endpoint_service_proto_depIdxs,
		MessageInfos:      file_yandex_cloud_dns_v1_dns_endpoint_service_proto_msgTypes,
	}.Build()
	File_yandex_cloud_dns_v1_dns_endpoint_service_proto = out.File
	file_yandex_cloud_dns_v1_dns_endpoint_service_proto_goTypes = nil
	file_yandex_cloud_dns_v1_dns_endpoint_service_proto_depIdxs = nil
}
