// Code generated by protoc-gen-goext. DO NOT EDIT.

package iam

func (m *ListSubjectAccessBindingsRequest) SetSubjectId(v string) {
	m.SubjectId = v
}

func (m *ListSubjectAccessBindingsRequest) SetOrganizationId(v string) {
	m.OrganizationId = v
}

func (m *ListSubjectAccessBindingsRequest) SetPageSize(v int64) {
	m.PageSize = v
}

func (m *ListSubjectAccessBindingsRequest) SetPageToken(v string) {
	m.PageToken = v
}

func (m *ListSubjectAccessBindingsResponse) SetSubjectAccessBindings(v []*SubjectAccessBinding) {
	m.SubjectAccessBindings = v
}

func (m *ListSubjectAccessBindingsResponse) SetNextPageToken(v string) {
	m.NextPageToken = v
}

func (m *SubjectAccessBinding) SetRoleId(v string) {
	m.RoleId = v
}

func (m *SubjectAccessBinding) SetResource(v *Resource) {
	m.Resource = v
}

func (m *SubjectAccessBinding) SetSubjectId(v string) {
	m.SubjectId = v
}
